@@ -1,6 +1,5 @@
 # CREATED:2015-09-16 14:46:47 by Brian McFee <brian.mcfee@nyu.edu>
-# -*- encoding: utf-8 -*-
-'''Evaluation criteria for hierarchical structure analysis.
+"""Evaluation criteria for hierarchical structure analysis.
 
 Hierarchical structure analysis seeks to annotate a track with a nested
 decomposition of the temporal elements of the piece, effectively providing
@@ -39,7 +38,7 @@ References
     Juan P. Bello.
     "Evaluating hierarchical structure in music annotations",
     Frontiers in Psychology, 2017.
-'''
+"""
 
 import collections
 import itertools
@@ -53,7 +52,7 @@ from .segment import validate_structure
 
 
 def _round(t, frame_size):
-    '''Round a time-stamp to a specified resolution.
+    """Round a time-stamp to a specified resolution.
 
     Equivalent to ``t - np.mod(t, frame_size)``.
 
@@ -68,7 +67,6 @@ def _round(t, frame_size):
     ----------
     t : number or ndarray
         The time-stamp to round
-
     frame_size : number > 0
         The resolution to round to
 
@@ -76,12 +74,12 @@ def _round(t, frame_size):
     -------
     t_round : number
         The rounded time-stamp
-    '''
+    """
     return t - np.mod(t, float(frame_size))
 
 
 def _hierarchy_bounds(intervals_hier):
-    '''Compute the covered time range of a hierarchical segmentation.
+    """Compute the covered time range of a hierarchical segmentation.
 
     Parameters
     ----------
@@ -94,14 +92,14 @@ def _hierarchy_bounds(intervals_hier):
     t_min : float
     t_max : float
         The minimum and maximum times spanned by the annotation
-    '''
+    """
     boundaries = list(itertools.chain(*list(itertools.chain(*intervals_hier))))
 
     return min(boundaries), max(boundaries)
 
 
 def _align_intervals(int_hier, lab_hier, t_min=0.0, t_max=None):
-    '''Align a hierarchical annotation to span a fixed start and end time.
+    """Align a hierarchical annotation to span a fixed start and end time.
 
     Parameters
     ----------
@@ -110,10 +108,8 @@ def _align_intervals(int_hier, lab_hier, t_min=0.0, t_max=None):
         Hierarchical segment annotations, encoded as a
         list of list of intervals (int_hier) and list of
         list of strings (lab_hier)
-
     t_min : None or number >= 0
         The minimum time value for the segmentation
-
     t_max : None or number >= t_min
         The maximum time value for the segmentation
 
@@ -122,16 +118,22 @@ def _align_intervals(int_hier, lab_hier, t_min=0.0, t_max=None):
     intervals_hier : list of list of intervals
     labels_hier : list of list of str
         `int_hier` `lab_hier` aligned to span `[t_min, t_max]`.
-    '''
-    return [list(_) for _ in zip(*[util.adjust_intervals(np.asarray(ival),
-                                                         labels=lab,
-                                                         t_min=t_min,
-                                                         t_max=t_max)
-                                   for ival, lab in zip(int_hier, lab_hier)])]
+    """
+    return [
+        list(_)
+        for _ in zip(
+            *[
+                util.adjust_intervals(
+                    np.asarray(ival), labels=lab, t_min=t_min, t_max=t_max
+                )
+                for ival, lab in zip(int_hier, lab_hier)
+            ]
+        )
+    ]
 
 
 def _lca(intervals_hier, frame_size):
-    '''Compute the (sparse) least-common-ancestor (LCA) matrix for a
+    """Compute the (sparse) least-common-ancestor (LCA) matrix for a
     hierarchical segmentation.
 
     For any pair of frames ``(s, t)``, the LCA is the deepest level in
@@ -143,7 +145,6 @@ def _lca(intervals_hier, frame_size):
     intervals_hier : list of ndarray
         An ordered list of segment interval arrays.
         The list is assumed to be ordered by increasing specificity (depth).
-
     frame_size : number
         The length of the sample frames (in seconds)
 
@@ -152,23 +153,22 @@ def _lca(intervals_hier, frame_size):
     lca_matrix : scipy.sparse.csr_matrix
         A sparse matrix such that ``lca_matrix[i, j]`` contains the depth
         of the deepest segment containing frames ``i`` and ``j``.
-    '''
-
+    """
     frame_size = float(frame_size)
 
     # Figure out how many frames we need
 
     n_start, n_end = _hierarchy_bounds(intervals_hier)
 
-    n = int((_round(n_end, frame_size) -
-             _round(n_start, frame_size)) / frame_size)
+    n = int((_round(n_end, frame_size) - _round(n_start, frame_size)) / frame_size)
 
     # Initialize the LCA matrix
     lca_matrix = scipy.sparse.lil_matrix((n, n), dtype=np.uint8)
 
     for level, intervals in enumerate(intervals_hier, 1):
-        for ival in (_round(np.asarray(intervals),
-                            frame_size) / frame_size).astype(int):
+        for ival in (_round(np.asarray(intervals), frame_size) / frame_size).astype(
+            int
+        ):
             idx = slice(ival[0], ival[1])
             lca_matrix[idx, idx] = level
 
@@ -176,7 +176,7 @@ def _lca(intervals_hier, frame_size):
 
 
 def _meet(intervals_hier, labels_hier, frame_size):
-    '''Compute the (sparse) least-common-ancestor (LCA) matrix for a
+    """Compute the (sparse) least-common-ancestor (LCA) matrix for a
     hierarchical segmentation.
 
     For any pair of frames ``(s, t)``, the LCA is the deepest level in
@@ -188,11 +188,9 @@ def _meet(intervals_hier, labels_hier, frame_size):
     intervals_hier : list of ndarray
         An ordered list of segment interval arrays.
         The list is assumed to be ordered by increasing specificity (depth).
-
     labels_hier : list of list of str
         ``labels_hier[i]`` contains the segment labels for the
         ``i``th layer of the annotations
-
     frame_size : number
         The length of the sample frames (in seconds)
 
@@ -201,23 +199,19 @@ def _meet(intervals_hier, labels_hier, frame_size):
     meet_matrix : scipy.sparse.csr_matrix
         A sparse matrix such that ``meet_matrix[i, j]`` contains the depth
         of the deepest segment label containing both ``i`` and ``j``.
-    '''
-
+    """
     frame_size = float(frame_size)
 
     # Figure out how many frames we need
 
     n_start, n_end = _hierarchy_bounds(intervals_hier)
 
-    n = int((_round(n_end, frame_size) -
-             _round(n_start, frame_size)) / frame_size)
+    n = int((_round(n_end, frame_size) - _round(n_start, frame_size)) / frame_size)
 
     # Initialize the meet matrix
     meet_matrix = scipy.sparse.lil_matrix((n, n), dtype=np.uint8)
 
-    for level, (intervals, labels) in enumerate(zip(intervals_hier,
-                                                    labels_hier), 1):
-
+    for level, (intervals, labels) in enumerate(zip(intervals_hier, labels_hier), 1):
         # Encode the labels at this level
         lab_enc = util.index_labels(labels)[0]
 
@@ -228,7 +222,7 @@ def _meet(intervals_hier, labels_hier, frame_size):
         int_frames = (_round(intervals, frame_size) / frame_size).astype(int)
 
         # For each intervals i, j where labels agree, update the meet matrix
-        for (seg_i, seg_j) in zip(*np.where(int_agree)):
+        for seg_i, seg_j in zip(*np.where(int_agree)):
             idx_i = slice(*list(int_frames[seg_i]))
             idx_j = slice(*list(int_frames[seg_j]))
             meet_matrix[idx_i, idx_j] = level
@@ -239,7 +233,7 @@ def _meet(intervals_hier, labels_hier, frame_size):
 
 
 def _gauc(ref_lca, est_lca, transitive, window):
-    '''Generalized area under the curve (GAUC)
+    """Generalized area under the curve (GAUC)
 
     This function computes the normalized recall score for correctly
     ordering triples ``(q, i, j)`` where frames ``(q, i)`` are closer than
@@ -248,6 +242,7 @@ def _gauc(ref_lca, est_lca, transitive, window):
     Parameters
     ----------
     ref_lca : scipy.sparse
+
     est_lca : scipy.sparse
         The least common ancestor matrices for the reference and
         estimated annotations
@@ -273,12 +268,13 @@ def _gauc(ref_lca, est_lca, transitive, window):
     ------
     ValueError
         If ``ref_lca`` and ``est_lca`` have different shapes
-    '''
+    """
     # Make sure we have the right number of frames
 
     if ref_lca.shape != est_lca.shape:
-        raise ValueError('Estimated and reference hierarchies '
-                         'must have the same shape.')
+        raise ValueError(
+            "Estimated and reference hierarchies " "must have the same shape."
+        )
 
     # How many frames?
     n = ref_lca.shape[0]
@@ -294,7 +290,6 @@ def _gauc(ref_lca, est_lca, transitive, window):
     num_frames = 0
 
     for query in range(n):
-
         # Find all pairs i,j such that ref_lca[q, i] > ref_lca[q, j]
         results = slice(max(0, query - window), min(n, query + window))
 
@@ -311,11 +306,12 @@ def _gauc(ref_lca, est_lca, transitive, window):
         # (this also holds when the slice goes off the end of the array.)
         idx = min(query, window)
 
-        ref_score = np.concatenate((ref_score[:idx], ref_score[idx+1:]))
-        est_score = np.concatenate((est_score[:idx], est_score[idx+1:]))
+        ref_score = np.concatenate((ref_score[:idx], ref_score[idx + 1 :]))
+        est_score = np.concatenate((est_score[:idx], est_score[idx + 1 :]))
 
-        inversions, normalizer = _compare_frame_rankings(ref_score, est_score,
-                                                         transitive=transitive)
+        inversions, normalizer = _compare_frame_rankings(
+            ref_score, est_score, transitive=transitive
+        )
 
         if normalizer:
             score += 1.0 - inversions / float(normalizer)
@@ -332,7 +328,7 @@ def _gauc(ref_lca, est_lca, transitive, window):
 
 
 def _count_inversions(a, b):
-    '''Count the number of inversions in two numpy arrays:
+    """Count the number of inversions in two numpy arrays:
 
     # points i, j where a[i] >= b[j]
 
@@ -348,8 +344,7 @@ def _count_inversions(a, b):
     -------
     inversions : int
         The number of detected inversions
-    '''
-
+    """
     a, a_counts = np.unique(a, return_counts=True)
     b, b_counts = np.unique(b, return_counts=True)
 
@@ -368,7 +363,7 @@ def _count_inversions(a, b):
 
 
 def _compare_frame_rankings(ref, est, transitive=False):
-    '''Compute the number of ranking disagreements in two lists.
+    """Compute the number of ranking disagreements in two lists.
 
     Parameters
     ----------
@@ -376,7 +371,6 @@ def _compare_frame_rankings(ref, est, transitive=False):
     est : np.ndarray, shape=(n,)
         Reference and estimate ranked lists.
         `ref[i]` is the relevance score for point `i`.
-
     transitive : bool
         If true, all pairs of reference levels are compared.
         If false, only adjacent pairs of reference levels are compared.
@@ -386,21 +380,19 @@ def _compare_frame_rankings(ref, est, transitive=False):
     inversions : int
         The number of pairs of indices `i, j` where
         `ref[i] < ref[j]` but `est[i] >= est[j]`.
-
     normalizer : float
         The total number of pairs (i, j) under consideration.
         If transitive=True, then this is |{(i,j) : ref[i] < ref[j]}|
         If transitive=False, then this is |{i,j) : ref[i] +1 = ref[j]}|
-    '''
-
+    """
     idx = np.argsort(ref)
     ref_sorted = ref[idx]
     est_sorted = est[idx]
 
     # Find the break-points in ref_sorted
-    levels, positions, counts = np.unique(ref_sorted,
-                                          return_index=True,
-                                          return_counts=True)
+    levels, positions, counts = np.unique(
+        ref_sorted, return_index=True, return_counts=True
+    )
 
     positions = list(positions)
     positions.append(len(ref_sorted))
@@ -408,8 +400,7 @@ def _compare_frame_rankings(ref, est, transitive=False):
     index = collections.defaultdict(lambda: slice(0))
     ref_map = collections.defaultdict(lambda: 0)
 
-    for level, cnt, start, end in zip(levels, counts,
-                                      positions[:-1], positions[1:]):
+    for level, cnt, start, end in zip(levels, counts, positions[:-1], positions[1:]):
         index[level] = slice(start, end)
         ref_map[level] = cnt
 
@@ -418,7 +409,7 @@ def _compare_frame_rankings(ref, est, transitive=False):
     if transitive:
         level_pairs = itertools.combinations(levels, 2)
     else:
-        level_pairs = [(i, i+1) for i in levels]
+        level_pairs = [(i, i + 1) for i in levels]
 
     level_pairs, lcounter = itertools.tee(level_pairs)
 
@@ -430,14 +421,15 @@ def _compare_frame_rankings(ref, est, transitive=False):
     inversions = 0
 
     for level_1, level_2 in level_pairs:
-        inversions += _count_inversions(est_sorted[index[level_1]],
-                                        est_sorted[index[level_2]])
+        inversions += _count_inversions(
+            est_sorted[index[level_1]], est_sorted[index[level_2]]
+        )
 
     return inversions, float(normalizer)
 
 
 def validate_hier_intervals(intervals_hier):
-    '''Validate a hierarchical segment annotation.
+    """Validate a hierarchical segment annotation.
 
     Parameters
     ----------
@@ -450,8 +442,7 @@ def validate_hier_intervals(intervals_hier):
         segmentation.
 
         If any segmentation does not start at 0.
-    '''
-
+    """
     # Synthesize a label array for the top layer.
     label_top = util.generate_labels(intervals_hier[0])
 
@@ -460,21 +451,27 @@ def validate_hier_intervals(intervals_hier):
     for level, intervals in enumerate(intervals_hier[1:], 1):
         # Make sure this level is consistent with the root
         label_current = util.generate_labels(intervals)
-        validate_structure(intervals_hier[0], label_top,
-                           intervals, label_current)
+        validate_structure(intervals_hier[0], label_top, intervals, label_current)
 
         # Make sure all previous boundaries are accounted for
         new_bounds = set(util.intervals_to_boundaries(intervals))
 
         if boundaries - new_bounds:
-            warnings.warn('Segment hierarchy is inconsistent '
-                          'at level {:d}'.format(level))
+            warnings.warn(
+                "Segment hierarchy is inconsistent " "at level {:d}".format(level)
+            )
         boundaries |= new_bounds
 
 
-def tmeasure(reference_intervals_hier, estimated_intervals_hier,
-             transitive=False, window=15.0, frame_size=0.1, beta=1.0):
-    '''Computes the tree measures for hierarchical segment annotations.
+def tmeasure(
+    reference_intervals_hier,
+    estimated_intervals_hier,
+    transitive=False,
+    window=15.0,
+    frame_size=0.1,
+    beta=1.0,
+):
+    """Compute the tree measures for hierarchical segment annotations.
 
     Parameters
     ----------
@@ -483,21 +480,16 @@ def tmeasure(reference_intervals_hier, estimated_intervals_hier,
         (in seconds) for the ``i`` th layer of the annotations.  Layers are
         ordered from top to bottom, so that the last list of intervals should
         be the most specific.
-
     estimated_intervals_hier : list of ndarray
         Like ``reference_intervals_hier`` but for the estimated annotation
-
     transitive : bool
         whether to compute the t-measures using transitivity or not.
-
     window : float > 0
         size of the window (in seconds).  For each query frame q,
         result frames are only counted within q +- window.
-
     frame_size : float > 0
         length (in seconds) of frames.  The frame size cannot be longer than
         the window.
-
     beta : float > 0
         beta parameter for the F-measure.
 
@@ -505,10 +497,8 @@ def tmeasure(reference_intervals_hier, estimated_intervals_hier,
     -------
     t_precision : number [0, 1]
         T-measure Precision
-
     t_recall : number [0, 1]
         T-measure Recall
-
     t_measure : number [0, 1]
         F-beta measure for ``(t_precision, t_recall)``
 
@@ -520,19 +510,21 @@ def tmeasure(reference_intervals_hier, estimated_intervals_hier,
         If the input hierarchies have different time durations
 
         If ``frame_size > window`` or ``frame_size <= 0``
-    '''
-
+    """
     # Compute the number of frames in the window
     if frame_size <= 0:
-        raise ValueError('frame_size ({:.2f}) must be a positive '
-                         'number.'.format(frame_size))
+        raise ValueError(
+            "frame_size ({:.2f}) must be a positive " "number.".format(frame_size)
+        )
 
     if window is None:
         window_frames = None
     else:
         if frame_size > window:
-            raise ValueError('frame_size ({:.2f}) cannot exceed '
-                             'window ({:.2f})'.format(frame_size, window))
+            raise ValueError(
+                "frame_size ({:.2f}) cannot exceed "
+                "window ({:.2f})".format(frame_size, window)
+            )
 
         window_frames = int(_round(window, frame_size) / frame_size)
 
@@ -553,10 +545,15 @@ def tmeasure(reference_intervals_hier, estimated_intervals_hier,
     return t_precision, t_recall, t_measure
 
 
-def lmeasure(reference_intervals_hier, reference_labels_hier,
-             estimated_intervals_hier, estimated_labels_hier,
-             frame_size=0.1, beta=1.0):
-    '''Computes the tree measures for hierarchical segment annotations.
+def lmeasure(
+    reference_intervals_hier,
+    reference_labels_hier,
+    estimated_intervals_hier,
+    estimated_labels_hier,
+    frame_size=0.1,
+    beta=1.0,
+):
+    """Compute the tree measures for hierarchical segment annotations.
 
     Parameters
     ----------
@@ -565,20 +562,16 @@ def lmeasure(reference_intervals_hier, reference_labels_hier,
         (in seconds) for the ``i`` th layer of the annotations.  Layers are
         ordered from top to bottom, so that the last list of intervals should
         be the most specific.
-
     reference_labels_hier : list of list of str
         ``reference_labels_hier[i]`` contains the segment labels for the
-        ``i``th layer of the annotations
-
+        ``i`` th layer of the annotations
     estimated_intervals_hier : list of ndarray
     estimated_labels_hier : list of ndarray
         Like ``reference_intervals_hier`` and ``reference_labels_hier``
         but for the estimated annotation
-
     frame_size : float > 0
         length (in seconds) of frames.  The frame size cannot be longer than
         the window.
-
     beta : float > 0
         beta parameter for the F-measure.
 
@@ -586,10 +579,8 @@ def lmeasure(reference_intervals_hier, reference_labels_hier,
     -------
     l_precision : number [0, 1]
         L-measure Precision
-
     l_recall : number [0, 1]
         L-measure Recall
-
     l_measure : number [0, 1]
         F-beta measure for ``(l_precision, l_recall)``
 
@@ -601,22 +592,20 @@ def lmeasure(reference_intervals_hier, reference_labels_hier,
         If the input hierarchies have different time durations
 
         If ``frame_size > window`` or ``frame_size <= 0``
-    '''
-
+    """
     # Compute the number of frames in the window
     if frame_size <= 0:
-        raise ValueError('frame_size ({:.2f}) must be a positive '
-                         'number.'.format(frame_size))
+        raise ValueError(
+            "frame_size ({:.2f}) must be a positive " "number.".format(frame_size)
+        )
 
     # Validate the hierarchical segmentations
     validate_hier_intervals(reference_intervals_hier)
     validate_hier_intervals(estimated_intervals_hier)
 
     # Build the least common ancestor matrices
-    ref_meet = _meet(reference_intervals_hier, reference_labels_hier,
-                     frame_size)
-    est_meet = _meet(estimated_intervals_hier, estimated_labels_hier,
-                     frame_size)
+    ref_meet = _meet(reference_intervals_hier, reference_labels_hier, frame_size)
+    est_meet = _meet(estimated_intervals_hier, estimated_labels_hier, frame_size)
 
     # Compute precision and recall
     l_recall = _gauc(ref_meet, est_meet, True, None)
@@ -627,9 +616,10 @@ def lmeasure(reference_intervals_hier, reference_labels_hier,
     return l_precision, l_recall, l_measure
 
 
-def evaluate(ref_intervals_hier, ref_labels_hier,
-             est_intervals_hier, est_labels_hier, **kwargs):
-    '''Compute all hierarchical structure metrics for the given reference and
+def evaluate(
+    ref_intervals_hier, ref_labels_hier, est_intervals_hier, est_labels_hier, **kwargs
+):
+    r"""Compute all hierarchical structure metrics for the given reference and
     estimated annotations.
 
     Examples
@@ -676,7 +666,6 @@ def evaluate(ref_intervals_hier, ref_labels_hier,
      'T-Recall full': 0.6523334654992341,
      'T-Recall reduced': 0.60799919710921635}
 
-
     Parameters
     ----------
     ref_intervals_hier : list of list-like
@@ -687,13 +676,12 @@ def evaluate(ref_intervals_hier, ref_labels_hier,
         of segmentations.  Each segmentation itself is a list (or list-like)
         of intervals (\*_intervals_hier) and a list of lists of labels
         (\*_labels_hier).
-
-    kwargs
+    **kwargs
         additional keyword arguments to the evaluation metrics.
 
     Returns
     -------
-    scores :  OrderedDict
+    scores : OrderedDict
         Dictionary of scores, where the key is the metric name (str) and
         the value is the (float) score achieved.
 
@@ -704,48 +692,47 @@ def evaluate(ref_intervals_hier, ref_labels_hier,
     ------
     ValueError
         Thrown when the provided annotations are not valid.
-    '''
-
+    """
     # First, find the maximum length of the reference
     _, t_end = _hierarchy_bounds(ref_intervals_hier)
 
     # Pre-process the intervals to match the range of the reference,
     # and start at 0
-    ref_intervals_hier, ref_labels_hier = _align_intervals(ref_intervals_hier,
-                                                           ref_labels_hier,
-                                                           t_min=0.0,
-                                                           t_max=None)
+    ref_intervals_hier, ref_labels_hier = _align_intervals(
+        ref_intervals_hier, ref_labels_hier, t_min=0.0, t_max=None
+    )
 
-    est_intervals_hier, est_labels_hier = _align_intervals(est_intervals_hier,
-                                                           est_labels_hier,
-                                                           t_min=0.0,
-                                                           t_max=t_end)
+    est_intervals_hier, est_labels_hier = _align_intervals(
+        est_intervals_hier, est_labels_hier, t_min=0.0, t_max=t_end
+    )
 
     scores = collections.OrderedDict()
 
     # Force the transitivity setting
-    kwargs['transitive'] = False
-    (scores['T-Precision reduced'],
-     scores['T-Recall reduced'],
-     scores['T-Measure reduced']) = util.filter_kwargs(tmeasure,
-                                                       ref_intervals_hier,
-                                                       est_intervals_hier,
-                                                       **kwargs)
+    kwargs["transitive"] = False
+    (
+        scores["T-Precision reduced"],
+        scores["T-Recall reduced"],
+        scores["T-Measure reduced"],
+    ) = util.filter_kwargs(tmeasure, ref_intervals_hier, est_intervals_hier, **kwargs)
 
-    kwargs['transitive'] = True
-    (scores['T-Precision full'],
-     scores['T-Recall full'],
-     scores['T-Measure full']) = util.filter_kwargs(tmeasure,
-                                                    ref_intervals_hier,
-                                                    est_intervals_hier,
-                                                    **kwargs)
+    kwargs["transitive"] = True
+    (
+        scores["T-Precision full"],
+        scores["T-Recall full"],
+        scores["T-Measure full"],
+    ) = util.filter_kwargs(tmeasure, ref_intervals_hier, est_intervals_hier, **kwargs)
 
-    (scores['L-Precision'],
-     scores['L-Recall'],
-     scores['L-Measure']) = util.filter_kwargs(lmeasure,
-                                               ref_intervals_hier,
-                                               ref_labels_hier,
-                                               est_intervals_hier,
-                                               est_labels_hier,
-                                               **kwargs)
+    (
+        scores["L-Precision"],
+        scores["L-Recall"],
+        scores["L-Measure"],
+    ) = util.filter_kwargs(
+        lmeasure,
+        ref_intervals_hier,
+        ref_labels_hier,
+        est_intervals_hier,
+        est_labels_hier,
+        **kwargs
+    )
     return scores
