@@ -1,13 +1,10 @@
-"""
-Functions for loading in annotations from files in different formats.
-"""
+"""Functions for loading annotations from files in different formats."""
 
 import contextlib
 import numpy as np
 import re
 import warnings
 import scipy.io.wavfile
-import six
 
 from . import util
 from . import key
@@ -15,28 +12,26 @@ from . import tempo
 
 
 @contextlib.contextmanager
-def _open(file_or_str, **kwargs):
-    '''Either open a file handle, or use an existing file-like object.
+def _open(file_or_path, **kwargs):
+    """Either open a file handle, or use an existing file-like object.
 
-    This will behave as the `open` function if `file_or_str` is a string.
+    If `file_or_path` has the `read` attribute, it will return `file_or_path`.
 
-    If `file_or_str` has the `read` attribute, it will return `file_or_str`.
-
-    Otherwise, an `IOError` is raised.
-    '''
-    if hasattr(file_or_str, 'read'):
-        yield file_or_str
-    elif isinstance(file_or_str, six.string_types):
-        with open(file_or_str, **kwargs) as file_desc:
-            yield file_desc
+    Otherwise, it will attempt to open the file at the specified location.
+    """
+    if hasattr(file_or_path, "read"):
+        yield file_or_path
     else:
-        raise IOError('Invalid file-or-str object: {}'.format(file_or_str))
+        try:
+            with open(file_or_path, **kwargs) as file_desc:
+                yield file_desc
+        except TypeError as exc:
+            raise IOError(f"Invalid file-or-path object: {file_or_path}") from exc
 
 
-def load_delimited(filename, converters, delimiter=r'\s+', comment='#'):
-    r"""Utility function for loading in data from an annotation file where columns
-    are delimited.  The number of columns is inferred from the length of
-    the provided converters list.
+def load_delimited(filename, converters, delimiter=r"\s+", comment="#"):
+    r"""Load data from an annotation file where columns are delimited.
+    The number of columns is inferred from the length of the provided converters list.
 
     Examples
     --------
@@ -47,14 +42,17 @@ def load_delimited(filename, converters, delimiter=r'\s+', comment='#'):
 
     Parameters
     ----------
-    filename : str
+    filename : str or `os.Pathlike`
         Path to the annotation file
+
     converters : list of functions
         Each entry in column ``n`` of the file will be cast by the function
         ``converters[n]``.
+
     delimiter : str
         Separator regular expression.
         By default, lines will be split by any amount of whitespace.
+
     comment : str or None
         Comment regular expression.
         Any lines beginning with this string or pattern will be ignored.
@@ -66,7 +64,6 @@ def load_delimited(filename, converters, delimiter=r'\s+', comment='#'):
     columns : tuple of lists
         Each list in this tuple corresponds to values in one of the columns
         in the file.
-
     """
     # Initialize list of empty lists
     n_columns = len(converters)
@@ -79,7 +76,7 @@ def load_delimited(filename, converters, delimiter=r'\s+', comment='#'):
     if comment is None:
         commenter = None
     else:
-        commenter = re.compile('^{}'.format(comment))
+        commenter = re.compile(f"^{comment}")
 
     # Note: we do io manually here for two reasons.
     #   1. The csv module has difficulties with unicode, which may lead
@@ -87,7 +84,7 @@ def load_delimited(filename, converters, delimiter=r'\s+', comment='#'):
     #
     #   2. numpy's text loader does not handle non-numeric data
     #
-    with _open(filename, mode='r') as input_file:
+    with _open(filename, mode="r") as input_file:
         for row, line in enumerate(input_file, 1):
             # Skip commented lines
             if comment is not None and commenter.match(line):
@@ -98,19 +95,22 @@ def load_delimited(filename, converters, delimiter=r'\s+', comment='#'):
 
             # Throw a helpful error if we got an unexpected # of columns
             if n_columns != len(data):
-                raise ValueError('Expected {} columns, got {} at '
-                                 '{}:{:d}:\n\t{}'.format(n_columns, len(data),
-                                                         filename, row, line))
+                raise ValueError(
+                    "Expected {} columns, got {} at "
+                    "{}:{:d}:\n\t{}".format(n_columns, len(data), filename, row, line)
+                )
 
             for value, column, converter in zip(data, columns, converters):
                 # Try converting the value, throw a helpful error on failure
                 try:
                     converted_value = converter(value)
                 except:
-                    raise ValueError("Couldn't convert value {} using {} "
-                                     "found at {}:{:d}:\n\t{}".format(
-                                         value, converter.__name__, filename,
-                                         row, line))
+                    raise ValueError(
+                        "Couldn't convert value {} using {} "
+                        "found at {}:{:d}:\n\t{}".format(
+                            value, converter.__name__, filename, row, line
+                        )
+                    )
                 column.append(converted_value)
 
     # Sane output
@@ -120,7 +120,7 @@ def load_delimited(filename, converters, delimiter=r'\s+', comment='#'):
         return columns
 
 
-def load_events(filename, delimiter=r'\s+', comment='#'):
+def load_events(filename, delimiter=r"\s+", comment="#"):
     r"""Import time-stamp events from an annotation file.  The file should
     consist of a single column of numeric values corresponding to the event
     times. This is primarily useful for processing events which lack duration,
@@ -128,11 +128,13 @@ def load_events(filename, delimiter=r'\s+', comment='#'):
 
     Parameters
     ----------
-    filename : str
+    filename : str or `os.Pathlike`
         Path to the annotation file
+
     delimiter : str
         Separator regular expression.
         By default, lines will be split by any amount of whitespace.
+
     comment : str or None
         Comment regular expression.
         Any lines beginning with this string or pattern will be ignored.
@@ -146,8 +148,7 @@ def load_events(filename, delimiter=r'\s+', comment='#'):
 
     """
     # Use our universal function to load in the events
-    events = load_delimited(filename, [float],
-                            delimiter=delimiter, comment=comment)
+    events = load_delimited(filename, [float], delimiter=delimiter, comment=comment)
     events = np.array(events)
     # Validate them, but throw a warning in place of an error
     try:
@@ -158,7 +159,7 @@ def load_events(filename, delimiter=r'\s+', comment='#'):
     return events
 
 
-def load_labeled_events(filename, delimiter=r'\s+', comment='#'):
+def load_labeled_events(filename, delimiter=r"\s+", comment="#"):
     r"""Import labeled time-stamp events from an annotation file.  The file should
     consist of two columns; the first having numeric values corresponding to
     the event times and the second having string labels for each event.  This
@@ -167,11 +168,13 @@ def load_labeled_events(filename, delimiter=r'\s+', comment='#'):
 
     Parameters
     ----------
-    filename : str
+    filename : str or `os.Pathlike`
         Path to the annotation file
+
     delimiter : str
         Separator regular expression.
         By default, lines will be split by any amount of whitespace.
+
     comment : str or None
         Comment regular expression.
         Any lines beginning with this string or pattern will be ignored.
@@ -187,9 +190,9 @@ def load_labeled_events(filename, delimiter=r'\s+', comment='#'):
 
     """
     # Use our universal function to load in the events
-    events, labels = load_delimited(filename, [float, str],
-                                    delimiter=delimiter,
-                                    comment=comment)
+    events, labels = load_delimited(
+        filename, [float, str], delimiter=delimiter, comment=comment
+    )
     events = np.array(events)
     # Validate them, but throw a warning in place of an error
     try:
@@ -200,7 +203,7 @@ def load_labeled_events(filename, delimiter=r'\s+', comment='#'):
     return events, labels
 
 
-def load_intervals(filename, delimiter=r'\s+', comment='#'):
+def load_intervals(filename, delimiter=r"\s+", comment="#"):
     r"""Import intervals from an annotation file.  The file should consist of two
     columns of numeric values corresponding to start and end time of each
     interval.  This is primarily useful for processing events which span a
@@ -208,11 +211,13 @@ def load_intervals(filename, delimiter=r'\s+', comment='#'):
 
     Parameters
     ----------
-    filename : str
+    filename : str or `os.Pathlike`
         Path to the annotation file
+
     delimiter : str
         Separator regular expression.
         By default, lines will be split by any amount of whitespace.
+
     comment : str or None
         Comment regular expression.
         Any lines beginning with this string or pattern will be ignored.
@@ -226,9 +231,9 @@ def load_intervals(filename, delimiter=r'\s+', comment='#'):
 
     """
     # Use our universal function to load in the events
-    starts, ends = load_delimited(filename, [float, float],
-                                  delimiter=delimiter,
-                                  comment=comment)
+    starts, ends = load_delimited(
+        filename, [float, float], delimiter=delimiter, comment=comment
+    )
     # Stack into an interval matrix
     intervals = np.array([starts, ends]).T
     # Validate them, but throw a warning in place of an error
@@ -240,7 +245,7 @@ def load_intervals(filename, delimiter=r'\s+', comment='#'):
     return intervals
 
 
-def load_labeled_intervals(filename, delimiter=r'\s+', comment='#'):
+def load_labeled_intervals(filename, delimiter=r"\s+", comment="#"):
     r"""Import labeled intervals from an annotation file.  The file should consist
     of three columns: Two consisting of numeric values corresponding to start
     and end time of each interval and a third corresponding to the label of
@@ -249,11 +254,13 @@ def load_labeled_intervals(filename, delimiter=r'\s+', comment='#'):
 
     Parameters
     ----------
-    filename : str
+    filename : str or `os.Pathlike`
         Path to the annotation file
+
     delimiter : str
         Separator regular expression.
         By default, lines will be split by any amount of whitespace.
+
     comment : str or None
         Comment regular expression.
         Any lines beginning with this string or pattern will be ignored.
@@ -269,9 +276,9 @@ def load_labeled_intervals(filename, delimiter=r'\s+', comment='#'):
 
     """
     # Use our universal function to load in the events
-    starts, ends, labels = load_delimited(filename, [float, float, str],
-                                          delimiter=delimiter,
-                                          comment=comment)
+    starts, ends, labels = load_delimited(
+        filename, [float, float, str], delimiter=delimiter, comment=comment
+    )
     # Stack into an interval matrix
     intervals = np.array([starts, ends]).T
     # Validate them, but throw a warning in place of an error
@@ -283,18 +290,20 @@ def load_labeled_intervals(filename, delimiter=r'\s+', comment='#'):
     return intervals, labels
 
 
-def load_time_series(filename, delimiter=r'\s+', comment='#'):
+def load_time_series(filename, delimiter=r"\s+", comment="#"):
     r"""Import a time series from an annotation file.  The file should consist of
     two columns of numeric values corresponding to the time and value of each
     sample of the time series.
 
     Parameters
     ----------
-    filename : str
+    filename : str or `os.Pathlike`
         Path to the annotation file
+
     delimiter : str
         Separator regular expression.
         By default, lines will be split by any amount of whitespace.
+
     comment : str or None
         Comment regular expression.
         Any lines beginning with this string or pattern will be ignored.
@@ -310,9 +319,9 @@ def load_time_series(filename, delimiter=r'\s+', comment='#'):
 
     """
     # Use our universal function to load in the events
-    times, values = load_delimited(filename, [float, float],
-                                   delimiter=delimiter,
-                                   comment=comment)
+    times, values = load_delimited(
+        filename, [float, float], delimiter=delimiter, comment=comment
+    )
     times = np.array(times)
     values = np.array(values)
 
@@ -320,7 +329,7 @@ def load_time_series(filename, delimiter=r'\s+', comment='#'):
 
 
 def load_patterns(filename):
-    """Loads the patters contained in the filename and puts them into a list
+    """Load the patterns contained in the filename and puts them into a list
     of patterns, each pattern being a list of occurrence, and each
     occurrence being a list of (onset, midi) pairs.
 
@@ -329,7 +338,7 @@ def load_patterns(filename):
 
     Parameters
     ----------
-    filename : str
+    filename : str or `os.Pathlike`
         The input file path containing the patterns of a given piece using the
         MIREX 2013 format.
 
@@ -361,16 +370,14 @@ def load_patterns(filename):
             pattern2 = [occ1, occ2]
 
             pattern_list = [pattern1, pattern2]
-
     """
-
     # List with all the patterns
     pattern_list = []
     # Current pattern, which will contain all occs
     pattern = []
     # Current occurrence, containing (onset, midi)
     occurrence = []
-    with _open(filename, mode='r') as input_file:
+    with _open(filename, mode="r") as input_file:
         for line in input_file.readlines():
             if "pattern" in line:
                 if occurrence != []:
@@ -398,12 +405,18 @@ def load_patterns(filename):
     return pattern_list
 
 
+@util.deprecated(version="0.8.1", version_removed="0.9.0")
 def load_wav(path, mono=True):
-    """Loads a .wav file as a numpy array using ``scipy.io.wavfile``.
+    """Load a .wav file as a numpy array using ``scipy.io.wavfile``.
+
+    .. warning:: This function is deprecatred in mir_eval 0.8.1
+        and will be removed in 0.9.0.
+        We recommend using a dedicated audio IO library such as
+        `soundfile` instead.
 
     Parameters
     ----------
-    path : str
+    path : str or `os.Pathlike`
         Path to a .wav file
     mono : bool
         If the provided .wav has more than one channel, it will be
@@ -415,27 +428,24 @@ def load_wav(path, mono=True):
         Array of audio samples, normalized to the range [-1., 1.]
     fs : int
         Sampling rate of the audio data
-
     """
-
     fs, audio_data = scipy.io.wavfile.read(path)
     # Make float in range [-1, 1]
-    if audio_data.dtype == 'int8':
-        audio_data = audio_data/float(2**8)
-    elif audio_data.dtype == 'int16':
-        audio_data = audio_data/float(2**16)
-    elif audio_data.dtype == 'int32':
-        audio_data = audio_data/float(2**24)
+    if audio_data.dtype == "int8":
+        audio_data = audio_data / float(2**8)
+    elif audio_data.dtype == "int16":
+        audio_data = audio_data / float(2**16)
+    elif audio_data.dtype == "int32":
+        audio_data = audio_data / float(2**24)
     else:
-        raise ValueError('Got unexpected .wav data type '
-                         '{}'.format(audio_data.dtype))
+        raise ValueError("Got unexpected .wav data type " "{}".format(audio_data.dtype))
     # Optionally convert to mono
     if mono and audio_data.ndim != 1:
         audio_data = audio_data.mean(axis=1)
     return audio_data, fs
 
 
-def load_valued_intervals(filename, delimiter=r'\s+', comment='#'):
+def load_valued_intervals(filename, delimiter=r"\s+", comment="#"):
     r"""Import valued intervals from an annotation file. The file should
     consist of three columns: Two consisting of numeric values corresponding to
     start and end time of each interval and a third, also of numeric values,
@@ -445,11 +455,13 @@ def load_valued_intervals(filename, delimiter=r'\s+', comment='#'):
 
     Parameters
     ----------
-    filename : str
+    filename : str or `os.Pathlike`
         Path to the annotation file
+
     delimiter : str
         Separator regular expression.
         By default, lines will be split by any amount of whitespace.
+
     comment : str or None
         Comment regular expression.
         Any lines beginning with this string or pattern will be ignored.
@@ -465,9 +477,9 @@ def load_valued_intervals(filename, delimiter=r'\s+', comment='#'):
 
     """
     # Use our universal function to load in the events
-    starts, ends, values = load_delimited(filename, [float, float, float],
-                                          delimiter=delimiter,
-                                          comment=comment)
+    starts, ends, values = load_delimited(
+        filename, [float, float, float], delimiter=delimiter, comment=comment
+    )
     # Stack into an interval matrix
     intervals = np.array([starts, ends]).T
     # Validate them, but throw a warning in place of an error
@@ -482,7 +494,7 @@ def load_valued_intervals(filename, delimiter=r'\s+', comment='#'):
     return intervals, values
 
 
-def load_key(filename, delimiter=r'\s+', comment='#'):
+def load_key(filename, delimiter=r"\s+", comment="#"):
     r"""Load key labels from an annotation file. The file should
     consist of two string columns: One denoting the key scale degree
     (semitone), and the other denoting the mode (major or minor).  The file
@@ -490,11 +502,13 @@ def load_key(filename, delimiter=r'\s+', comment='#'):
 
     Parameters
     ----------
-    filename : str
+    filename : str or `os.Pathlike`
         Path to the annotation file
+
     delimiter : str
         Separator regular expression.
         By default, lines will be split by any amount of whitespace.
+
     comment : str or None
         Comment regular expression.
         Any lines beginning with this string or pattern will be ignored.
@@ -508,14 +522,14 @@ def load_key(filename, delimiter=r'\s+', comment='#'):
 
     """
     # Use our universal function to load the key and mode strings
-    scale, mode = load_delimited(filename, [str, str],
-                                 delimiter=delimiter,
-                                 comment=comment)
+    scale, mode = load_delimited(
+        filename, [str, str], delimiter=delimiter, comment=comment
+    )
     if len(scale) != 1:
-        raise ValueError('Key file should contain only one line.')
+        raise ValueError("Key file should contain only one line.")
     scale, mode = scale[0], mode[0]
     # Join with a space
-    key_string = '{} {}'.format(scale, mode)
+    key_string = f"{scale} {mode}"
     # Validate them, but throw a warning in place of an error
     try:
         key.validate_key(key_string)
@@ -525,7 +539,7 @@ def load_key(filename, delimiter=r'\s+', comment='#'):
     return key_string
 
 
-def load_tempo(filename, delimiter=r'\s+', comment='#'):
+def load_tempo(filename, delimiter=r"\s+", comment="#"):
     r"""Load tempo estimates from an annotation file in MIREX format.
     The file should consist of three numeric columns: the first two
     correspond to tempo estimates (in beats-per-minute), and the third
@@ -534,11 +548,13 @@ def load_tempo(filename, delimiter=r'\s+', comment='#'):
 
     Parameters
     ----------
-    filename : str
+    filename : str or `os.Pathlike`
         Path to the annotation file
+
     delimiter : str
         Separator regular expression.
         By default, lines will be split by any amount of whitespace.
+
     comment : str or None
         Comment regular expression.
         Any lines beginning with this string or pattern will be ignored.
@@ -549,20 +565,19 @@ def load_tempo(filename, delimiter=r'\s+', comment='#'):
     -------
     tempi : np.ndarray, non-negative
         The two tempo estimates
-
     weight : float [0, 1]
         The relative importance of ``tempi[0]`` compared to ``tempi[1]``
     """
     # Use our universal function to load the key and mode strings
-    t1, t2, weight = load_delimited(filename, [float, float, float],
-                                    delimiter=delimiter,
-                                    comment=comment)
+    t1, t2, weight = load_delimited(
+        filename, [float, float, float], delimiter=delimiter, comment=comment
+    )
 
     weight = weight[0]
     tempi = np.concatenate([t1, t2])
 
     if len(t1) != 1:
-        raise ValueError('Tempo file should contain only one line.')
+        raise ValueError("Tempo file should contain only one line.")
 
     # Validate them, but throw a warning in place of an error
     try:
@@ -571,17 +586,20 @@ def load_tempo(filename, delimiter=r'\s+', comment='#'):
         warnings.warn(error.args[0])
 
     if not 0 <= weight <= 1:
-        raise ValueError('Invalid weight: {}'.format(weight))
+        raise ValueError(f"Invalid weight: {weight}")
 
     return tempi, weight
 
 
-def load_ragged_time_series(filename, dtype=float, delimiter=r'\s+',
-                            header=False, comment='#'):
-    r"""Utility function for loading in data from a delimited time series
-    annotation file with a variable number of columns.
-    Assumes that column 0 contains time stamps and columns 1 through n contain
-    values. n may be variable from time stamp to time stamp.
+def load_ragged_time_series(
+    filename, dtype=float, delimiter=r"\s+", header=False, comment="#"
+):
+    r"""Load data from a delimited time series annotation file with
+    a variable number of columns.
+
+    This function assumes that column 0 contains time stamps and
+    columns 1 through n contain values.
+    n may be variable from time stamp to time stamp.
 
     Examples
     --------
@@ -594,16 +612,20 @@ def load_ragged_time_series(filename, dtype=float, delimiter=r'\s+',
 
     Parameters
     ----------
-    filename : str
+    filename : str or `os.Pathlike`
         Path to the annotation file
+
     dtype : function
         Data type to apply to values columns.
+
     delimiter : str
         Separator regular expression.
         By default, lines will be split by any amount of whitespace.
+
     header : bool
         Indicates whether a header row is present or not.
         By default, assumes no header is present.
+
     comment : str or None
         Comment regular expression.
         Any lines beginning with this string or pattern will be ignored.
@@ -629,13 +651,13 @@ def load_ragged_time_series(filename, dtype=float, delimiter=r'\s+',
     if comment is None:
         commenter = None
     else:
-        commenter = re.compile('^{}'.format(comment))
+        commenter = re.compile(f"^{comment}")
 
     if header:
         start_row = 1
     else:
         start_row = 0
-    with _open(filename, mode='r') as input_file:
+    with _open(filename, mode="r") as input_file:
         for row, line in enumerate(input_file, start_row):
             # If this is a comment line, skip it
             if comment is not None and commenter.match(line):
@@ -646,10 +668,12 @@ def load_ragged_time_series(filename, dtype=float, delimiter=r'\s+',
             try:
                 converted_time = float(data[0])
             except (TypeError, ValueError) as exe:
-                six.raise_from(ValueError("Couldn't convert value {} using {} "
-                                          "found at {}:{:d}:\n\t{}".format(
-                                            data[0], float.__name__,
-                                            filename, row, line)), exe)
+                raise ValueError(
+                    "Couldn't convert value {} using {} "
+                    "found at {}:{:d}:\n\t{}".format(
+                        data[0], float.__name__, filename, row, line
+                    )
+                ) from exe
             times.append(converted_time)
 
             # cast values to a numpy array. time stamps with no values are cast
@@ -657,10 +681,12 @@ def load_ragged_time_series(filename, dtype=float, delimiter=r'\s+',
             try:
                 converted_value = np.array(data[1:], dtype=dtype)
             except (TypeError, ValueError) as exe:
-                six.raise_from(ValueError("Couldn't convert value {} using {} "
-                                          "found at {}:{:d}:\n\t{}".format(
-                                            data[1:], dtype.__name__,
-                                            filename, row, line)), exe)
+                raise ValueError(
+                    "Couldn't convert value {} using {} "
+                    "found at {}:{:d}:\n\t{}".format(
+                        data[1:], dtype.__name__, filename, row, line
+                    )
+                ) from exe
             values.append(converted_value)
 
     return np.array(times), values
