@@ -1,5 +1,5 @@
 # CREATED:2013-08-13 12:02:42 by Brian McFee <brm2132@columbia.edu>
-'''
+"""
 Evaluation criteria for structural segmentation fall into two categories:
 boundary annotation and structural annotation.  Boundary annotation is the task
 of predicting the times at which structural changes occur, such as when a verse
@@ -70,7 +70,7 @@ References
         V-Measure: A Conditional Entropy-Based External Cluster Evaluation
         Measure.
         In EMNLP-CoNLL (Vol. 7, pp. 410-420).
-'''
+"""
 
 import collections
 import warnings
@@ -78,14 +78,13 @@ import warnings
 import numpy as np
 import scipy.stats
 import scipy.sparse
-import scipy.misc
 import scipy.special
 
 from . import util
 
 
 def validate_boundary(reference_intervals, estimated_intervals, trim):
-    """Checks that the input annotations to a segment boundary estimation
+    """Check that the input annotations to a segment boundary estimation
     metric (i.e. one that only takes in segment intervals) look like valid
     segment times, and throws helpful errors if not.
 
@@ -95,17 +94,13 @@ def validate_boundary(reference_intervals, estimated_intervals, trim):
         reference segment intervals, in the format returned by
         :func:`mir_eval.io.load_intervals` or
         :func:`mir_eval.io.load_labeled_intervals`.
-
     estimated_intervals : np.ndarray, shape=(m, 2)
         estimated segment intervals, in the format returned by
         :func:`mir_eval.io.load_intervals` or
         :func:`mir_eval.io.load_labeled_intervals`.
-
     trim : bool
         will the start and end events be trimmed?
-
     """
-
     if trim:
         # If we're trimming, then we need at least 2 intervals
         min_size = 2
@@ -123,9 +118,10 @@ def validate_boundary(reference_intervals, estimated_intervals, trim):
         util.validate_intervals(intervals)
 
 
-def validate_structure(reference_intervals, reference_labels,
-                       estimated_intervals, estimated_labels):
-    """Checks that the input annotations to a structure estimation metric (i.e.
+def validate_structure(
+    reference_intervals, reference_labels, estimated_intervals, estimated_labels
+):
+    """Check that the input annotations to a structure estimation metric (i.e.
     one that takes in both segment boundaries and their labels) look like valid
     segment times and labels, and throws helpful errors if not.
 
@@ -134,33 +130,30 @@ def validate_structure(reference_intervals, reference_labels,
     reference_intervals : np.ndarray, shape=(n, 2)
         reference segment intervals, in the format returned by
         :func:`mir_eval.io.load_labeled_intervals`.
-
     reference_labels : list, shape=(n,)
         reference segment labels, in the format returned by
         :func:`mir_eval.io.load_labeled_intervals`.
-
     estimated_intervals : np.ndarray, shape=(m, 2)
         estimated segment intervals, in the format returned by
         :func:`mir_eval.io.load_labeled_intervals`.
-
     estimated_labels : list, shape=(m,)
         estimated segment labels, in the format returned by
         :func:`mir_eval.io.load_labeled_intervals`.
 
     """
-    for (intervals, labels) in [(reference_intervals, reference_labels),
-                                (estimated_intervals, estimated_labels)]:
-
+    for intervals, labels in [
+        (reference_intervals, reference_labels),
+        (estimated_intervals, estimated_labels),
+    ]:
         util.validate_intervals(intervals)
         if intervals.shape[0] != len(labels):
-            raise ValueError('Number of intervals does not match number '
-                             'of labels')
+            raise ValueError("Number of intervals does not match number " "of labels")
 
         # Check only when intervals are non-empty
         if intervals.size > 0:
             # Make sure intervals start at 0
             if not np.allclose(intervals.min(), 0.0):
-                raise ValueError('Segment intervals do not start at 0')
+                raise ValueError("Segment intervals do not start at 0")
 
     if reference_intervals.size == 0:
         warnings.warn("Reference intervals are empty.")
@@ -168,13 +161,13 @@ def validate_structure(reference_intervals, reference_labels,
         warnings.warn("Estimated intervals are empty.")
     # Check only when intervals are non-empty
     if reference_intervals.size > 0 and estimated_intervals.size > 0:
-        if not np.allclose(reference_intervals.max(),
-                           estimated_intervals.max()):
-            raise ValueError('End times do not match')
+        if not np.allclose(reference_intervals.max(), estimated_intervals.max()):
+            raise ValueError("End times do not match")
 
 
-def detection(reference_intervals, estimated_intervals,
-              window=0.5, beta=1.0, trim=False):
+def detection(
+    reference_intervals, estimated_intervals, window=0.5, beta=1.0, trim=False
+):
     """Boundary detection hit-rate.
 
     A hit is counted whenever an reference boundary is within ``window`` of a
@@ -230,9 +223,7 @@ def detection(reference_intervals, estimated_intervals,
         recall of reference reference boundaries
     f_measure : float
         F-measure (weighted harmonic mean of ``precision`` and ``recall``)
-
     """
-
     validate_boundary(reference_intervals, estimated_intervals, trim)
 
     # Convert intervals to boundaries
@@ -248,9 +239,7 @@ def detection(reference_intervals, estimated_intervals,
     if len(reference_boundaries) == 0 or len(estimated_boundaries) == 0:
         return 0.0, 0.0, 0.0
 
-    matching = util.match_events(reference_boundaries,
-                                 estimated_boundaries,
-                                 window)
+    matching = util.match_events(reference_boundaries, estimated_boundaries, window)
 
     precision = float(len(matching)) / len(estimated_boundaries)
     recall = float(len(matching)) / len(reference_boundaries)
@@ -294,9 +283,7 @@ def deviation(reference_intervals, estimated_intervals, trim=False):
     estimated_to_reference : float
         median time from each estimated boundary to the
         closest reference boundary
-
     """
-
     validate_boundary(reference_intervals, estimated_intervals, trim)
 
     # Convert intervals to boundaries
@@ -312,8 +299,7 @@ def deviation(reference_intervals, estimated_intervals, trim=False):
     if len(reference_boundaries) == 0 or len(estimated_boundaries) == 0:
         return np.nan, np.nan
 
-    dist = np.abs(np.subtract.outer(reference_boundaries,
-                                    estimated_boundaries))
+    dist = np.abs(np.subtract.outer(reference_boundaries, estimated_boundaries))
 
     estimated_to_reference = np.median(dist.min(axis=0))
     reference_to_estimated = np.median(dist.min(axis=1))
@@ -321,9 +307,14 @@ def deviation(reference_intervals, estimated_intervals, trim=False):
     return reference_to_estimated, estimated_to_reference
 
 
-def pairwise(reference_intervals, reference_labels,
-             estimated_intervals, estimated_labels,
-             frame_size=0.1, beta=1.0):
+def pairwise(
+    reference_intervals,
+    reference_labels,
+    estimated_intervals,
+    estimated_labels,
+    frame_size=0.1,
+    beta=1.0,
+):
     """Frame-clustering segmentation evaluation by pair-wise agreement.
 
     Examples
@@ -376,25 +367,26 @@ def pairwise(reference_intervals, reference_labels,
         F-measure of detecting whether frames belong in the same cluster
 
     """
-    validate_structure(reference_intervals, reference_labels,
-                       estimated_intervals, estimated_labels)
+    validate_structure(
+        reference_intervals, reference_labels, estimated_intervals, estimated_labels
+    )
 
     # Check for empty annotations.  Don't need to check labels because
     # validate_structure makes sure they're the same size as intervals
     if reference_intervals.size == 0 or estimated_intervals.size == 0:
-        return 0., 0., 0.
+        return 0.0, 0.0, 0.0
 
     # Generate the cluster labels
-    y_ref = util.intervals_to_samples(reference_intervals,
-                                      reference_labels,
-                                      sample_size=frame_size)[-1]
+    y_ref = util.intervals_to_samples(
+        reference_intervals, reference_labels, sample_size=frame_size
+    )[-1]
 
     y_ref = util.index_labels(y_ref)[0]
 
     # Map to index space
-    y_est = util.intervals_to_samples(estimated_intervals,
-                                      estimated_labels,
-                                      sample_size=frame_size)[-1]
+    y_est = util.intervals_to_samples(
+        estimated_intervals, estimated_labels, sample_size=frame_size
+    )[-1]
 
     y_est = util.index_labels(y_est)[0]
 
@@ -418,9 +410,14 @@ def pairwise(reference_intervals, reference_labels,
     return precision, recall, f_measure
 
 
-def rand_index(reference_intervals, reference_labels,
-               estimated_intervals, estimated_labels,
-               frame_size=0.1, beta=1.0):
+def rand_index(
+    reference_intervals,
+    reference_labels,
+    estimated_intervals,
+    estimated_labels,
+    frame_size=0.1,
+    beta=1.0,
+):
     """(Non-adjusted) Rand index.
 
     Examples
@@ -467,28 +464,27 @@ def rand_index(reference_intervals, reference_labels,
     -------
     rand_index : float > 0
         Rand index
-
     """
-
-    validate_structure(reference_intervals, reference_labels,
-                       estimated_intervals, estimated_labels)
+    validate_structure(
+        reference_intervals, reference_labels, estimated_intervals, estimated_labels
+    )
 
     # Check for empty annotations.  Don't need to check labels because
     # validate_structure makes sure they're the same size as intervals
     if reference_intervals.size == 0 or estimated_intervals.size == 0:
-        return 0., 0., 0.
+        return 0.0, 0.0, 0.0
 
     # Generate the cluster labels
-    y_ref = util.intervals_to_samples(reference_intervals,
-                                      reference_labels,
-                                      sample_size=frame_size)[-1]
+    y_ref = util.intervals_to_samples(
+        reference_intervals, reference_labels, sample_size=frame_size
+    )[-1]
 
     y_ref = util.index_labels(y_ref)[0]
 
     # Map to index space
-    y_est = util.intervals_to_samples(estimated_intervals,
-                                      estimated_labels,
-                                      sample_size=frame_size)[-1]
+    y_est = util.intervals_to_samples(
+        estimated_intervals, estimated_labels, sample_size=frame_size
+    )[-1]
 
     y_est = util.index_labels(y_est)[0]
 
@@ -514,7 +510,7 @@ def rand_index(reference_intervals, reference_labels,
 
 
 def _contingency_matrix(reference_indices, estimated_indices):
-    """Computes the contingency matrix of a true labeling vs an estimated one.
+    """Compute the contingency matrix of a true labeling vs an estimated one.
 
     Parameters
     ----------
@@ -530,17 +526,16 @@ def _contingency_matrix(reference_indices, estimated_indices):
     .. note:: Based on sklearn.metrics.cluster.contingency_matrix
 
     """
-    ref_classes, ref_class_idx = np.unique(reference_indices,
-                                           return_inverse=True)
-    est_classes, est_class_idx = np.unique(estimated_indices,
-                                           return_inverse=True)
+    ref_classes, ref_class_idx = np.unique(reference_indices, return_inverse=True)
+    est_classes, est_class_idx = np.unique(estimated_indices, return_inverse=True)
     n_ref_classes = ref_classes.shape[0]
     n_est_classes = est_classes.shape[0]
     # Using coo_matrix is faster than histogram2d
-    return scipy.sparse.coo_matrix((np.ones(ref_class_idx.shape[0]),
-                                    (ref_class_idx, est_class_idx)),
-                                   shape=(n_ref_classes, n_est_classes),
-                                   dtype=np.int).toarray()
+    return scipy.sparse.coo_matrix(
+        (np.ones(ref_class_idx.shape[0]), (ref_class_idx, est_class_idx)),
+        shape=(n_ref_classes, n_est_classes),
+        dtype=np.int64,
+    ).toarray()
 
 
 def _adjusted_rand_index(reference_indices, estimated_indices):
@@ -557,7 +552,6 @@ def _adjusted_rand_index(reference_indices, estimated_indices):
     -------
     ari : float
         Adjusted Rand index
-
     .. note:: Based on sklearn.metrics.cluster.adjusted_rand_score
 
     """
@@ -567,32 +561,39 @@ def _adjusted_rand_index(reference_indices, estimated_indices):
     # Special limit cases: no clustering since the data is not split;
     # or trivial clustering where each document is assigned a unique cluster.
     # These are perfect matches hence return 1.0.
-    if (ref_classes.shape[0] == est_classes.shape[0] == 1 or
-        ref_classes.shape[0] == est_classes.shape[0] == 0 or
-        (ref_classes.shape[0] == est_classes.shape[0] ==
-         len(reference_indices))):
+    if (
+        ref_classes.shape[0] == est_classes.shape[0] == 1
+        or ref_classes.shape[0] == est_classes.shape[0] == 0
+        or (ref_classes.shape[0] == est_classes.shape[0] == len(reference_indices))
+    ):
         return 1.0
 
     contingency = _contingency_matrix(reference_indices, estimated_indices)
 
     # Compute the ARI using the contingency data
-    sum_comb_c = sum(scipy.special.comb(n_c, 2, exact=1) for n_c in
-                     contingency.sum(axis=1))
-    sum_comb_k = sum(scipy.special.comb(n_k, 2, exact=1) for n_k in
-                     contingency.sum(axis=0))
+    sum_comb_c = sum(
+        scipy.special.comb(n_c, 2, exact=1) for n_c in contingency.sum(axis=1)
+    )
+    sum_comb_k = sum(
+        scipy.special.comb(n_k, 2, exact=1) for n_k in contingency.sum(axis=0)
+    )
 
-    sum_comb = sum((scipy.special.comb(n_ij, 2, exact=1) for n_ij in
-                    contingency.flatten()))
-    prod_comb = (sum_comb_c * sum_comb_k)/float(scipy.special.comb(n_samples,
-                                                                   2))
-    mean_comb = (sum_comb_k + sum_comb_c)/2.
-    return (sum_comb - prod_comb)/(mean_comb - prod_comb)
+    sum_comb = sum(
+        scipy.special.comb(n_ij, 2, exact=1) for n_ij in contingency.flatten()
+    )
+    prod_comb = (sum_comb_c * sum_comb_k) / float(scipy.special.comb(n_samples, 2))
+    mean_comb = (sum_comb_k + sum_comb_c) / 2.0
+    return (sum_comb - prod_comb) / (mean_comb - prod_comb)
 
 
-def ari(reference_intervals, reference_labels,
-        estimated_intervals, estimated_labels,
-        frame_size=0.1):
-    """Adjusted Rand Index (ARI) for frame clustering segmentation evaluation.
+def ari(
+    reference_intervals,
+    reference_labels,
+    estimated_intervals,
+    estimated_labels,
+    frame_size=0.1,
+):
+    """Compute the Adjusted Rand Index (ARI) for frame clustering segmentation evaluation.
 
     Examples
     --------
@@ -635,25 +636,26 @@ def ari(reference_intervals, reference_labels,
         Adjusted Rand index between segmentations.
 
     """
-    validate_structure(reference_intervals, reference_labels,
-                       estimated_intervals, estimated_labels)
+    validate_structure(
+        reference_intervals, reference_labels, estimated_intervals, estimated_labels
+    )
 
     # Check for empty annotations.  Don't need to check labels because
     # validate_structure makes sure they're the same size as intervals
     if reference_intervals.size == 0 or estimated_intervals.size == 0:
-        return 0., 0., 0.
+        return 0.0, 0.0, 0.0
 
     # Generate the cluster labels
-    y_ref = util.intervals_to_samples(reference_intervals,
-                                      reference_labels,
-                                      sample_size=frame_size)[-1]
+    y_ref = util.intervals_to_samples(
+        reference_intervals, reference_labels, sample_size=frame_size
+    )[-1]
 
     y_ref = util.index_labels(y_ref)[0]
 
     # Map to index space
-    y_est = util.intervals_to_samples(estimated_intervals,
-                                      estimated_labels,
-                                      sample_size=frame_size)[-1]
+    y_est = util.intervals_to_samples(
+        estimated_intervals, estimated_labels, sample_size=frame_size
+    )[-1]
 
     y_est = util.index_labels(y_est)[0]
 
@@ -677,13 +679,13 @@ def _mutual_info_score(reference_indices, estimated_indices, contingency=None):
     -------
     mi : float
         Mutual information
-
     .. note:: Based on sklearn.metrics.cluster.mutual_info_score
 
     """
     if contingency is None:
-        contingency = _contingency_matrix(reference_indices,
-                                          estimated_indices).astype(float)
+        contingency = _contingency_matrix(reference_indices, estimated_indices).astype(
+            float
+        )
     contingency_sum = np.sum(contingency)
     pi = np.sum(contingency, axis=1)
     pj = np.sum(contingency, axis=0)
@@ -696,13 +698,15 @@ def _mutual_info_score(reference_indices, estimated_indices, contingency=None):
     # log(a / b) should be calculated as log(a) - log(b) for
     # possible loss of precision
     log_outer = -np.log(outer[nnz]) + np.log(pi.sum()) + np.log(pj.sum())
-    mi = (contingency_nm * (log_contingency_nm - np.log(contingency_sum)) +
-          contingency_nm * log_outer)
+    mi = (
+        contingency_nm * (log_contingency_nm - np.log(contingency_sum))
+        + contingency_nm * log_outer
+    )
     return mi.sum()
 
 
 def _entropy(labels):
-    """Calculates the entropy for a labeling.
+    """Calculate the entropy for a labeling.
 
     Parameters
     ----------
@@ -713,14 +717,13 @@ def _entropy(labels):
     -------
     entropy : float
         Entropy of the labeling.
-
     .. note:: Based on sklearn.metrics.cluster.entropy
 
     """
     if len(labels) == 0:
         return 1.0
     label_idx = np.unique(labels, return_inverse=True)[1]
-    pi = np.bincount(label_idx).astype(np.float)
+    pi = np.bincount(label_idx).astype(np.float64)
     pi = pi[pi > 0]
     pi_sum = np.sum(pi)
     # log(a / b) should be calculated as log(a) - log(b) for
@@ -736,7 +739,6 @@ def _adjusted_mutual_info_score(reference_indices, estimated_indices):
     ----------
     reference_indices : np.ndarray
         Array of reference indices
-
     estimated_indices : np.ndarray
         Array of estimated indices
 
@@ -744,7 +746,6 @@ def _adjusted_mutual_info_score(reference_indices, estimated_indices):
     -------
     ami : float <= 1.0
         Mutual information
-
     .. note:: Based on sklearn.metrics.cluster.adjusted_mutual_info_score
         and sklearn.metrics.cluster.expected_mutual_info_score
 
@@ -754,14 +755,18 @@ def _adjusted_mutual_info_score(reference_indices, estimated_indices):
     est_classes = np.unique(estimated_indices)
     # Special limit cases: no clustering since the data is not split.
     # This is a perfect match hence return 1.0.
-    if (ref_classes.shape[0] == est_classes.shape[0] == 1 or
-            ref_classes.shape[0] == est_classes.shape[0] == 0):
+    if (
+        ref_classes.shape[0] == est_classes.shape[0] == 1
+        or ref_classes.shape[0] == est_classes.shape[0] == 0
+    ):
         return 1.0
-    contingency = _contingency_matrix(reference_indices,
-                                      estimated_indices).astype(float)
+    contingency = _contingency_matrix(reference_indices, estimated_indices).astype(
+        float
+    )
     # Calculate the MI for the two clusterings
-    mi = _mutual_info_score(reference_indices, estimated_indices,
-                            contingency=contingency)
+    mi = _mutual_info_score(
+        reference_indices, estimated_indices, contingency=contingency
+    )
     # The following code is based on
     # sklearn.metrics.cluster.expected_mutual_information
     R, C = contingency.shape
@@ -771,7 +776,7 @@ def _adjusted_mutual_info_score(reference_indices, estimated_indices):
     # There are three major terms to the EMI equation, which are multiplied to
     # and then summed over varying nij values.
     # While nijs[0] will never be used, having it simplifies the indexing.
-    nijs = np.arange(0, max(np.max(a), np.max(b)) + 1, dtype='float')
+    nijs = np.arange(0, max(np.max(a), np.max(b)) + 1, dtype="float")
     # Stops divide by zero warnings. As its not used, no issue.
     nijs[0] = 1
     # term1 is nij / N
@@ -790,7 +795,7 @@ def _adjusted_mutual_info_score(reference_indices, estimated_indices):
     gln_N = scipy.special.gammaln(N + 1)
     gln_nij = scipy.special.gammaln(nijs + 1)
     # start and end values for nij terms for each summation.
-    start = np.array([[v - N + w for w in b] for v in a], dtype='int')
+    start = np.array([[v - N + w for w in b] for v in a], dtype="int")
     start = np.maximum(start, 1)
     end = np.minimum(np.resize(a, (C, R)).T, np.resize(b, (R, C))) + 1
     # emi itself is a summation over the various values.
@@ -800,13 +805,19 @@ def _adjusted_mutual_info_score(reference_indices, estimated_indices):
             for nij in range(start[i, j], end[i, j]):
                 term2 = log_Nnij[nij] - log_ab_outer[i, j]
                 # Numerators are positive, denominators are negative.
-                gln = (gln_a[i] + gln_b[j] + gln_Na[i] + gln_Nb[j] -
-                       gln_N - gln_nij[nij] -
-                       scipy.special.gammaln(a[i] - nij + 1) -
-                       scipy.special.gammaln(b[j] - nij + 1) -
-                       scipy.special.gammaln(N - a[i] - b[j] + nij + 1))
+                gln = (
+                    gln_a[i]
+                    + gln_b[j]
+                    + gln_Na[i]
+                    + gln_Nb[j]
+                    - gln_N
+                    - gln_nij[nij]
+                    - scipy.special.gammaln(a[i] - nij + 1)
+                    - scipy.special.gammaln(b[j] - nij + 1)
+                    - scipy.special.gammaln(N - a[i] - b[j] + nij + 1)
+                )
                 term3 = np.exp(gln)
-                emi += (term1[nij] * term2 * term3)
+                emi += term1[nij] * term2 * term3
     # Calculate entropy for each labeling
     h_true, h_pred = _entropy(reference_indices), _entropy(estimated_indices)
     ami = (mi - emi) / (max(h_true, h_pred) - emi)
@@ -821,7 +832,6 @@ def _normalized_mutual_info_score(reference_indices, estimated_indices):
     ----------
     reference_indices : np.ndarray
         Array of reference indices
-
     estimated_indices : np.ndarray
         Array of estimated indices
 
@@ -829,7 +839,6 @@ def _normalized_mutual_info_score(reference_indices, estimated_indices):
     -------
     nmi : float <= 1.0
         Normalized mutual information
-
     .. note:: Based on sklearn.metrics.cluster.normalized_mutual_info_score
 
     """
@@ -837,15 +846,19 @@ def _normalized_mutual_info_score(reference_indices, estimated_indices):
     est_classes = np.unique(estimated_indices)
     # Special limit cases: no clustering since the data is not split.
     # This is a perfect match hence return 1.0.
-    if (ref_classes.shape[0] == est_classes.shape[0] == 1 or
-            ref_classes.shape[0] == est_classes.shape[0] == 0):
+    if (
+        ref_classes.shape[0] == est_classes.shape[0] == 1
+        or ref_classes.shape[0] == est_classes.shape[0] == 0
+    ):
         return 1.0
-    contingency = _contingency_matrix(reference_indices,
-                                      estimated_indices).astype(float)
-    contingency = np.array(contingency, dtype='float')
+    contingency = _contingency_matrix(reference_indices, estimated_indices).astype(
+        float
+    )
+    contingency = np.array(contingency, dtype="float")
     # Calculate the MI for the two clusterings
-    mi = _mutual_info_score(reference_indices, estimated_indices,
-                            contingency=contingency)
+    mi = _mutual_info_score(
+        reference_indices, estimated_indices, contingency=contingency
+    )
     # Calculate the expected value for the mutual information
     # Calculate entropy for each labeling
     h_true, h_pred = _entropy(reference_indices), _entropy(estimated_indices)
@@ -853,9 +866,13 @@ def _normalized_mutual_info_score(reference_indices, estimated_indices):
     return nmi
 
 
-def mutual_information(reference_intervals, reference_labels,
-                       estimated_intervals, estimated_labels,
-                       frame_size=0.1):
+def mutual_information(
+    reference_intervals,
+    reference_labels,
+    estimated_intervals,
+    estimated_labels,
+    frame_size=0.1,
+):
     """Frame-clustering segmentation: mutual information metrics.
 
     Examples
@@ -905,25 +922,26 @@ def mutual_information(reference_intervals, reference_labels,
         Normalize mutual information between segmentations
 
     """
-    validate_structure(reference_intervals, reference_labels,
-                       estimated_intervals, estimated_labels)
+    validate_structure(
+        reference_intervals, reference_labels, estimated_intervals, estimated_labels
+    )
 
     # Check for empty annotations.  Don't need to check labels because
     # validate_structure makes sure they're the same size as intervals
     if reference_intervals.size == 0 or estimated_intervals.size == 0:
-        return 0., 0., 0.
+        return 0.0, 0.0, 0.0
 
     # Generate the cluster labels
-    y_ref = util.intervals_to_samples(reference_intervals,
-                                      reference_labels,
-                                      sample_size=frame_size)[-1]
+    y_ref = util.intervals_to_samples(
+        reference_intervals, reference_labels, sample_size=frame_size
+    )[-1]
 
     y_ref = util.index_labels(y_ref)[0]
 
     # Map to index space
-    y_est = util.intervals_to_samples(estimated_intervals,
-                                      estimated_labels,
-                                      sample_size=frame_size)[-1]
+    y_est = util.intervals_to_samples(
+        estimated_intervals, estimated_labels, sample_size=frame_size
+    )[-1]
 
     y_est = util.index_labels(y_est)[0]
 
@@ -939,8 +957,15 @@ def mutual_information(reference_intervals, reference_labels,
     return mutual_info, adj_mutual_info, norm_mutual_info
 
 
-def nce(reference_intervals, reference_labels, estimated_intervals,
-        estimated_labels, frame_size=0.1, beta=1.0, marginal=False):
+def nce(
+    reference_intervals,
+    reference_labels,
+    estimated_intervals,
+    estimated_labels,
+    frame_size=0.1,
+    beta=1.0,
+    marginal=False,
+):
     """Frame-clustering segmentation: normalized conditional entropy
 
     Computes cross-entropy of cluster assignment, normalized by the
@@ -985,7 +1010,6 @@ def nce(reference_intervals, reference_labels, estimated_intervals,
     beta : float > 0
         beta for F-measure
         (Default value = 1.0)
-
     marginal : bool
         If `False`, normalize conditional entropy by uniform entropy.
         If `True`, normalize conditional entropy by the marginal entropy.
@@ -1001,7 +1025,6 @@ def nce(reference_intervals, reference_labels, estimated_intervals,
         - For `marginal=True`, ``1 - H(y_est | y_ref) / H(y_est)``
 
         If `|y_est|==1`, then `S_over` will be 0.
-
     S_under
         Under-clustering score:
 
@@ -1010,31 +1033,29 @@ def nce(reference_intervals, reference_labels, estimated_intervals,
         - For `marginal=True`, ``1 - H(y_ref | y_est) / H(y_ref)``
 
         If `|y_ref|==1`, then `S_under` will be 0.
-
     S_F
         F-measure for (S_over, S_under)
-
     """
-
-    validate_structure(reference_intervals, reference_labels,
-                       estimated_intervals, estimated_labels)
+    validate_structure(
+        reference_intervals, reference_labels, estimated_intervals, estimated_labels
+    )
 
     # Check for empty annotations.  Don't need to check labels because
     # validate_structure makes sure they're the same size as intervals
     if reference_intervals.size == 0 or estimated_intervals.size == 0:
-        return 0., 0., 0.
+        return 0.0, 0.0, 0.0
 
     # Generate the cluster labels
-    y_ref = util.intervals_to_samples(reference_intervals,
-                                      reference_labels,
-                                      sample_size=frame_size)[-1]
+    y_ref = util.intervals_to_samples(
+        reference_intervals, reference_labels, sample_size=frame_size
+    )[-1]
 
     y_ref = util.index_labels(y_ref)[0]
 
     # Map to index space
-    y_est = util.intervals_to_samples(estimated_intervals,
-                                      estimated_labels,
-                                      sample_size=frame_size)[-1]
+    y_est = util.intervals_to_samples(
+        estimated_intervals, estimated_labels, sample_size=frame_size
+    )[-1]
 
     y_est = util.index_labels(y_est)[0]
 
@@ -1065,19 +1086,25 @@ def nce(reference_intervals, reference_labels, estimated_intervals,
 
     score_under = 0.0
     if z_ref > 0:
-        score_under = 1. - true_given_est / z_ref
+        score_under = 1.0 - true_given_est / z_ref
 
     score_over = 0.0
     if z_est > 0:
-        score_over = 1. - pred_given_ref / z_est
+        score_over = 1.0 - pred_given_ref / z_est
 
     f_measure = util.f_measure(score_over, score_under, beta=beta)
 
     return score_over, score_under, f_measure
 
 
-def vmeasure(reference_intervals, reference_labels, estimated_intervals,
-             estimated_labels, frame_size=0.1, beta=1.0):
+def vmeasure(
+    reference_intervals,
+    reference_labels,
+    estimated_intervals,
+    estimated_labels,
+    frame_size=0.1,
+    beta=1.0,
+):
     """Frame-clustering segmentation: v-measure
 
     Computes cross-entropy of cluster assignment, normalized by the
@@ -1132,22 +1159,23 @@ def vmeasure(reference_intervals, reference_labels, estimated_intervals,
         ``1 - H(y_est | y_ref) / H(y_est)``
 
         If `|y_est|==1`, then `V_precision` will be 0.
-
     V_recall
         Under-clustering score:
         ``1 - H(y_ref | y_est) / H(y_ref)``
 
         If `|y_ref|==1`, then `V_recall` will be 0.
-
     V_F
         F-measure for (V_precision, V_recall)
-
     """
-
-    return nce(reference_intervals, reference_labels,
-               estimated_intervals, estimated_labels,
-               frame_size=frame_size, beta=beta,
-               marginal=True)
+    return nce(
+        reference_intervals,
+        reference_labels,
+        estimated_intervals,
+        estimated_labels,
+        frame_size=frame_size,
+        beta=beta,
+        marginal=True,
+    )
 
 
 def evaluate(ref_intervals, ref_labels, est_intervals, est_labels, **kwargs):
@@ -1176,7 +1204,7 @@ def evaluate(ref_intervals, ref_labels, est_intervals, est_labels, **kwargs):
     est_labels : list, shape=(m,)
         estimated segment labels, in the format returned by
         :func:`mir_eval.io.load_labeled_intervals`.
-    kwargs
+    **kwargs
         Additional keyword arguments which will be passed to the
         appropriate metric or preprocessing functions.
 
@@ -1185,68 +1213,84 @@ def evaluate(ref_intervals, ref_labels, est_intervals, est_labels, **kwargs):
     scores : dict
         Dictionary of scores, where the key is the metric name (str) and
         the value is the (float) score achieved.
-
     """
-
     # Adjust timespan of estimations relative to ground truth
-    ref_intervals, ref_labels = \
-        util.adjust_intervals(ref_intervals, labels=ref_labels, t_min=0.0)
+    ref_intervals, ref_labels = util.adjust_intervals(
+        ref_intervals, labels=ref_labels, t_min=0.0
+    )
 
-    est_intervals, est_labels = \
-        util.adjust_intervals(est_intervals, labels=est_labels, t_min=0.0,
-                              t_max=ref_intervals.max())
+    est_intervals, est_labels = util.adjust_intervals(
+        est_intervals, labels=est_labels, t_min=0.0, t_max=ref_intervals.max()
+    )
 
     # Now compute all the metrics
     scores = collections.OrderedDict()
 
     # Boundary detection
     # Force these values for window
-    kwargs['window'] = .5
-    scores['Precision@0.5'], scores['Recall@0.5'], scores['F-measure@0.5'] = \
-        util.filter_kwargs(detection, ref_intervals, est_intervals, **kwargs)
+    kwargs["window"] = 0.5
+    (
+        scores["Precision@0.5"],
+        scores["Recall@0.5"],
+        scores["F-measure@0.5"],
+    ) = util.filter_kwargs(detection, ref_intervals, est_intervals, **kwargs)
 
-    kwargs['window'] = 3.0
-    scores['Precision@3.0'], scores['Recall@3.0'], scores['F-measure@3.0'] = \
-        util.filter_kwargs(detection, ref_intervals, est_intervals, **kwargs)
+    kwargs["window"] = 3.0
+    (
+        scores["Precision@3.0"],
+        scores["Recall@3.0"],
+        scores["F-measure@3.0"],
+    ) = util.filter_kwargs(detection, ref_intervals, est_intervals, **kwargs)
 
     # Boundary deviation
-    scores['Ref-to-est deviation'], scores['Est-to-ref deviation'] = \
-        util.filter_kwargs(deviation, ref_intervals, est_intervals, **kwargs)
+    scores["Ref-to-est deviation"], scores["Est-to-ref deviation"] = util.filter_kwargs(
+        deviation, ref_intervals, est_intervals, **kwargs
+    )
 
     # Pairwise clustering
-    (scores['Pairwise Precision'],
-     scores['Pairwise Recall'],
-     scores['Pairwise F-measure']) = util.filter_kwargs(pairwise,
-                                                        ref_intervals,
-                                                        ref_labels,
-                                                        est_intervals,
-                                                        est_labels, **kwargs)
+    (
+        scores["Pairwise Precision"],
+        scores["Pairwise Recall"],
+        scores["Pairwise F-measure"],
+    ) = util.filter_kwargs(
+        pairwise, ref_intervals, ref_labels, est_intervals, est_labels, **kwargs
+    )
 
     # Rand index
-    scores['Rand Index'] = util.filter_kwargs(rand_index, ref_intervals,
-                                              ref_labels, est_intervals,
-                                              est_labels, **kwargs)
+    scores["Rand Index"] = util.filter_kwargs(
+        rand_index, ref_intervals, ref_labels, est_intervals, est_labels, **kwargs
+    )
     # Adjusted rand index
-    scores['Adjusted Rand Index'] = util.filter_kwargs(ari, ref_intervals,
-                                                       ref_labels,
-                                                       est_intervals,
-                                                       est_labels, **kwargs)
+    scores["Adjusted Rand Index"] = util.filter_kwargs(
+        ari, ref_intervals, ref_labels, est_intervals, est_labels, **kwargs
+    )
 
     # Mutual information metrics
-    (scores['Mutual Information'],
-     scores['Adjusted Mutual Information'],
-     scores['Normalized Mutual Information']) = \
-        util.filter_kwargs(mutual_information, ref_intervals, ref_labels,
-                           est_intervals, est_labels, **kwargs)
+    (
+        scores["Mutual Information"],
+        scores["Adjusted Mutual Information"],
+        scores["Normalized Mutual Information"],
+    ) = util.filter_kwargs(
+        mutual_information,
+        ref_intervals,
+        ref_labels,
+        est_intervals,
+        est_labels,
+        **kwargs
+    )
 
     # Conditional entropy metrics
-    scores['NCE Over'], scores['NCE Under'], scores['NCE F-measure'] = \
-        util.filter_kwargs(nce, ref_intervals, ref_labels, est_intervals,
-                           est_labels, **kwargs)
+    (
+        scores["NCE Over"],
+        scores["NCE Under"],
+        scores["NCE F-measure"],
+    ) = util.filter_kwargs(
+        nce, ref_intervals, ref_labels, est_intervals, est_labels, **kwargs
+    )
 
     # V-measure metrics
-    scores['V Precision'], scores['V Recall'], scores['V-measure'] = \
-        util.filter_kwargs(vmeasure, ref_intervals, ref_labels, est_intervals,
-                           est_labels, **kwargs)
+    scores["V Precision"], scores["V Recall"], scores["V-measure"] = util.filter_kwargs(
+        vmeasure, ref_intervals, ref_labels, est_intervals, est_labels, **kwargs
+    )
 
     return scores
