@@ -1,11 +1,12 @@
-'''
-This submodule collects useful functionality required across the task
-submodules, such as preprocessing, validation, and common computations.
-'''
+"""
+Useful functionality required across the task submodules,
+such as preprocessing, validation, and common computations.
+"""
 
 import os
 import inspect
-import six
+import warnings
+from decorator import decorator
 
 import numpy as np
 
@@ -18,7 +19,6 @@ def index_labels(labels, case_sensitive=False):
     labels : list of strings, shape=(n,)
         A list of annotations, e.g., segment or chord labels from an
         annotation file.
-
     case_sensitive : bool
         Set to True to enable case-sensitive label indexing
         (Default value = False)
@@ -30,9 +30,7 @@ def index_labels(labels, case_sensitive=False):
     index_to_label : dict
         Mapping to convert numerical indices back to labels.
         ``labels[i] == index_to_label[indices[i]]``
-
     """
-
     label_to_index = {}
     index_to_label = {}
 
@@ -52,7 +50,7 @@ def index_labels(labels, case_sensitive=False):
     return indices, index_to_label
 
 
-def generate_labels(items, prefix='__'):
+def generate_labels(items, prefix="__"):
     """Given an array of items (e.g. events, intervals), create a synthetic label
     for each event of the form '(label prefix)(item number)'
 
@@ -70,11 +68,10 @@ def generate_labels(items, prefix='__'):
         Synthetically generated labels
 
     """
-    return ['{}{}'.format(prefix, n) for n in range(len(items))]
+    return [f"{prefix}{n}" for n in range(len(items))]
 
 
-def intervals_to_samples(intervals, labels, offset=0, sample_size=0.1,
-                         fill_value=None):
+def intervals_to_samples(intervals, labels, offset=0, sample_size=0.1, fill_value=None):
     """Convert an array of labeled time intervals to annotated samples.
 
     Parameters
@@ -85,18 +82,14 @@ def intervals_to_samples(intervals, labels, offset=0, sample_size=0.1,
         :func:`mir_eval.io.load_labeled_intervals()`.
         The ``i`` th interval spans time ``intervals[i, 0]`` to
         ``intervals[i, 1]``.
-
     labels : list, shape=(n,)
         The annotation for each interval
-
     offset : float > 0
         Phase offset of the sampled time grid (in seconds)
         (Default value = 0)
-
     sample_size : float > 0
         duration of each sample to be generated (in seconds)
         (Default value = 0.1)
-
     fill_value : type(labels[0])
         Object to use for the label with out-of-range time points.
         (Default value = None)
@@ -105,7 +98,6 @@ def intervals_to_samples(intervals, labels, offset=0, sample_size=0.1,
     -------
     sample_times : list
         list of sample times
-
     sample_labels : list
         array of labels for each generated sample
 
@@ -113,15 +105,12 @@ def intervals_to_samples(intervals, labels, offset=0, sample_size=0.1,
     -----
         Intervals will be rounded down to the nearest multiple
         of ``sample_size``.
-
     """
-
     # Round intervals to the sample size
     num_samples = int(np.floor(intervals.max() / sample_size))
     sample_indices = np.arange(num_samples, dtype=np.float32)
-    sample_times = (sample_indices*sample_size + offset).tolist()
-    sampled_labels = interpolate_intervals(
-        intervals, labels, sample_times, fill_value)
+    sample_times = (sample_indices * sample_size + offset).tolist()
+    sampled_labels = interpolate_intervals(intervals, labels, sample_times, fill_value)
 
     return sample_times, sampled_labels
 
@@ -162,33 +151,31 @@ def interpolate_intervals(intervals, labels, time_points, fill_value=None):
     ValueError
         If `time_points` is not in non-decreasing order.
     """
-
     # Verify that time_points is sorted
     time_points = np.asarray(time_points)
 
     if np.any(time_points[1:] < time_points[:-1]):
-        raise ValueError('time_points must be in non-decreasing order')
+        raise ValueError("time_points must be in non-decreasing order")
 
     aligned_labels = [fill_value] * len(time_points)
 
-    starts = np.searchsorted(time_points, intervals[:, 0], side='left')
-    ends = np.searchsorted(time_points, intervals[:, 1], side='right')
+    starts = np.searchsorted(time_points, intervals[:, 0], side="left")
+    ends = np.searchsorted(time_points, intervals[:, 1], side="right")
 
-    for (start, end, lab) in zip(starts, ends, labels):
+    for start, end, lab in zip(starts, ends, labels):
         aligned_labels[start:end] = [lab] * (end - start)
 
     return aligned_labels
 
 
 def sort_labeled_intervals(intervals, labels=None):
-    '''Sort intervals, and optionally, their corresponding labels
+    """Sort intervals, and optionally, their corresponding labels
     according to start time.
 
     Parameters
     ----------
     intervals : np.ndarray, shape=(n, 2)
         The input intervals
-
     labels : list, optional
         Labels for each interval
 
@@ -196,8 +183,7 @@ def sort_labeled_intervals(intervals, labels=None):
     -------
     intervals_sorted or (intervals_sorted, labels_sorted)
         Labels are only returned if provided as input
-    '''
-
+    """
     idx = np.argsort(intervals[:, 0])
 
     intervals_sorted = intervals[idx]
@@ -225,13 +211,11 @@ def f_measure(precision, recall, beta=1.0):
     -------
     f_measure : float
         The weighted f-measure
-
     """
-
     if precision == 0 and recall == 0:
         return 0.0
 
-    return (1 + beta**2)*precision*recall/((beta**2)*precision + recall)
+    return (1 + beta**2) * precision * recall / ((beta**2) * precision + recall)
 
 
 def intervals_to_boundaries(intervals, q=5):
@@ -248,9 +232,7 @@ def intervals_to_boundaries(intervals, q=5):
     -------
     boundaries : np.ndarray
         Interval boundary times, including the end of the final interval
-
     """
-
     return np.unique(np.ravel(np.round(intervals, decimals=q)))
 
 
@@ -268,21 +250,22 @@ def boundaries_to_intervals(boundaries):
     intervals : np.ndarray, shape=(n_intervals, 2)
         Start and end time for each interval
     """
-
     if not np.allclose(boundaries, np.unique(boundaries)):
-        raise ValueError('Boundary times are not unique or not ascending.')
+        raise ValueError("Boundary times are not unique or not ascending.")
 
     intervals = np.asarray(list(zip(boundaries[:-1], boundaries[1:])))
 
     return intervals
 
 
-def adjust_intervals(intervals,
-                     labels=None,
-                     t_min=0.0,
-                     t_max=None,
-                     start_label='__T_MIN',
-                     end_label='__T_MAX'):
+def adjust_intervals(
+    intervals,
+    labels=None,
+    t_min=0.0,
+    t_max=None,
+    start_label="__T_MIN",
+    end_label="__T_MAX",
+):
     """Adjust a list of time intervals to span the range ``[t_min, t_max]``.
 
     Any intervals lying completely outside the specified range will be removed.
@@ -321,9 +304,7 @@ def adjust_intervals(intervals,
         Intervals spanning ``[t_min, t_max]``
     new_labels : list
         List of labels for ``new_labels``
-
     """
-
     # When supplied intervals are empty and t_max and t_min are supplied,
     # create one interval from t_min to t_max with the label start_label
     if t_min is not None and t_max is not None and intervals.size == 0:
@@ -331,8 +312,7 @@ def adjust_intervals(intervals,
     # When intervals are empty and either t_min or t_max are not supplied,
     # we can't append new intervals
     elif (t_min is None or t_max is None) and intervals.size == 0:
-        raise ValueError("Supplied intervals are empty, can't append new"
-                         " intervals")
+        raise ValueError("Supplied intervals are empty, can't append new" " intervals")
 
     if t_min is not None:
         # Find the intervals that end at or after t_min
@@ -341,9 +321,9 @@ def adjust_intervals(intervals,
         if len(first_idx) > 0:
             # If we have events below t_min, crop them out
             if labels is not None:
-                labels = labels[int(first_idx[0]):]
+                labels = labels[first_idx[0, 0] :]
             # Clip to the range (t_min, +inf)
-            intervals = intervals[int(first_idx[0]):]
+            intervals = intervals[first_idx[0, 0] :]
         intervals = np.maximum(t_min, intervals)
 
         if intervals.min() > t_min:
@@ -361,9 +341,9 @@ def adjust_intervals(intervals,
             # We have boundaries above t_max.
             # Trim to only boundaries <= t_max
             if labels is not None:
-                labels = labels[:int(last_idx[0])]
+                labels = labels[: last_idx[0, 0]]
             # Clip to the range (-inf, t_max)
-            intervals = intervals[:int(last_idx[0])]
+            intervals = intervals[: last_idx[0, 0]]
 
         intervals = np.minimum(t_max, intervals)
 
@@ -376,8 +356,7 @@ def adjust_intervals(intervals,
     return intervals, labels
 
 
-def adjust_events(events, labels=None, t_min=0.0,
-                  t_max=None, label_prefix='__'):
+def adjust_events(events, labels=None, t_min=0.0, t_max=None, label_prefix="__"):
     """Adjust the given list of event times to span the range
     ``[t_min, t_max]``.
 
@@ -416,15 +395,15 @@ def adjust_events(events, labels=None, t_min=0.0,
             # We have events below t_min
             # Crop them out
             if labels is not None:
-                labels = labels[int(first_idx[0]):]
-            events = events[int(first_idx[0]):]
+                labels = labels[first_idx[0, 0] :]
+            events = events[first_idx[0, 0] :]
 
         if events[0] > t_min:
             # Lowest boundary is higher than t_min:
             # add a new boundary and label
             events = np.concatenate(([t_min], events))
             if labels is not None:
-                labels.insert(0, '%sT_MIN' % label_prefix)
+                labels.insert(0, "%sT_MIN" % label_prefix)
 
     if t_max is not None:
         last_idx = np.argwhere(events > t_max)
@@ -433,14 +412,14 @@ def adjust_events(events, labels=None, t_min=0.0,
             # We have boundaries above t_max.
             # Trim to only boundaries <= t_max
             if labels is not None:
-                labels = labels[:int(last_idx[0])]
-            events = events[:int(last_idx[0])]
+                labels = labels[: last_idx[0, 0]]
+            events = events[: last_idx[0, 0]]
 
         if events[-1] < t_max:
             # Last boundary is below t_max: add a new boundary and label
             events = np.concatenate((events, [t_max]))
             if labels is not None:
-                labels.append('%sT_MAX' % label_prefix)
+                labels.append("%sT_MAX" % label_prefix)
 
     return events, labels
 
@@ -474,21 +453,22 @@ def intersect_files(flist1, flist2):
         corresponding filepaths from ``flist2``
 
     """
+
     def fname(abs_path):
-        """Returns the filename given an absolute path.
+        """Return the filename given an absolute path.
 
         Parameters
         ----------
-        abs_path :
-
+        abs_path
 
         Returns
         -------
+        filename
 
         """
         return os.path.splitext(os.path.split(abs_path)[-1])[0]
 
-    fmap = dict([(fname(f), f) for f in flist1])
+    fmap = {fname(f): f for f in flist1}
     pairs = [list(), list()]
     for f in flist2:
         if fname(f) in fmap:
@@ -522,16 +502,17 @@ def merge_labeled_intervals(x_intervals, x_labels, y_intervals, y_labels):
         New labels for the sequence ``y``
 
     """
-    align_check = [x_intervals[0, 0] == y_intervals[0, 0],
-                   x_intervals[-1, 1] == y_intervals[-1, 1]]
+    align_check = [
+        x_intervals[0, 0] == y_intervals[0, 0],
+        x_intervals[-1, 1] == y_intervals[-1, 1],
+    ]
     if False in align_check:
         raise ValueError(
             "Time intervals do not align; did you mean to call "
-            "'adjust_intervals()' first?")
-    time_boundaries = np.unique(
-        np.concatenate([x_intervals, y_intervals], axis=0))
-    output_intervals = np.array(
-        [time_boundaries[:-1], time_boundaries[1:]]).T
+            "'adjust_intervals()' first?"
+        )
+    time_boundaries = np.unique(np.concatenate([x_intervals, y_intervals], axis=0))
+    output_intervals = np.array([time_boundaries[:-1], time_boundaries[1:]]).T
 
     x_labels_out, y_labels_out = [], []
     x_label_range = np.arange(len(x_labels))
@@ -584,7 +565,7 @@ def _bipartite_match(graph):
         # layer
         preds = {}
         unmatched = []
-        pred = dict([(u, unmatched) for u in graph])
+        pred = {u: unmatched for u in graph}
         for v in matching:
             del pred[matching[v]]
         layer = list(pred)
@@ -711,7 +692,7 @@ def match_events(ref, est, window, distance=None):
 
 
 def _fast_hit_windows(ref, est, window):
-    '''Fast calculation of windowed hits for time events.
+    """Fast calculation of windowed hits for time events.
 
     Given two lists of event times ``ref`` and ``est``, and a
     tolerance window, computes a list of pairings
@@ -736,15 +717,14 @@ def _fast_hit_windows(ref, est, window):
     hit_ref : np.ndarray
     hit_est : np.ndarray
         indices such that ``|hit_ref[i] - hit_est[i]| <= window``
-    '''
-
+    """
     ref = np.asarray(ref)
     est = np.asarray(est)
     ref_idx = np.argsort(ref)
     ref_sorted = ref[ref_idx]
 
-    left_idx = np.searchsorted(ref_sorted, est - window, side='left')
-    right_idx = np.searchsorted(ref_sorted, est + window, side='right')
+    left_idx = np.searchsorted(ref_sorted, est - window, side="left")
+    right_idx = np.searchsorted(ref_sorted, est + window, side="right")
 
     hit_ref, hit_est = [], []
 
@@ -756,32 +736,32 @@ def _fast_hit_windows(ref, est, window):
 
 
 def validate_intervals(intervals):
-    """Checks that an (n, 2) interval ndarray is well-formed, and raises errors
+    """Check that an (n, 2) interval ndarray is well-formed, and raises errors
     if not.
 
     Parameters
     ----------
     intervals : np.ndarray, shape=(n, 2)
         Array of interval start/end locations.
-
     """
-
     # Validate interval shape
     if intervals.ndim != 2 or intervals.shape[1] != 2:
-        raise ValueError('Intervals should be n-by-2 numpy ndarray, '
-                         'but shape={}'.format(intervals.shape))
+        raise ValueError(
+            "Intervals should be n-by-2 numpy ndarray, "
+            "but shape={}".format(intervals.shape)
+        )
 
     # Make sure no times are negative
     if (intervals < 0).any():
-        raise ValueError('Negative interval times found')
+        raise ValueError("Negative interval times found")
 
     # Make sure all intervals have strictly positive duration
     if (intervals[:, 1] <= intervals[:, 0]).any():
-        raise ValueError('All interval durations must be strictly positive')
+        raise ValueError("All interval durations must be strictly positive")
 
 
-def validate_events(events, max_time=30000.):
-    """Checks that a 1-d event location ndarray is well-formed, and raises
+def validate_events(events, max_time=30000.0):
+    """Check that a 1-d event location ndarray is well-formed, and raises
     errors if not.
 
     Parameters
@@ -791,26 +771,28 @@ def validate_events(events, max_time=30000.):
     max_time : float
         If an event is found above this time, a ValueError will be raised.
         (Default value = 30000.)
-
     """
     # Make sure no event times are huge
     if (events > max_time).any():
-        raise ValueError('An event at time {} was found which is greater than '
-                         'the maximum allowable time of max_time = {} (did you'
-                         ' supply event times in '
-                         'seconds?)'.format(events.max(), max_time))
+        raise ValueError(
+            "An event at time {} was found which is greater than "
+            "the maximum allowable time of max_time = {} (did you"
+            " supply event times in "
+            "seconds?)".format(events.max(), max_time)
+        )
     # Make sure event locations are 1-d np ndarrays
     if events.ndim != 1:
-        raise ValueError('Event times should be 1-d numpy ndarray, '
-                         'but shape={}'.format(events.shape))
+        raise ValueError(
+            "Event times should be 1-d numpy ndarray, "
+            "but shape={}".format(events.shape)
+        )
     # Make sure event times are increasing
     if (np.diff(events) < 0).any():
-        raise ValueError('Events should be in increasing order.')
+        raise ValueError("Events should be in increasing order.")
 
 
-def validate_frequencies(frequencies, max_freq, min_freq,
-                         allow_negatives=False):
-    """Checks that a 1-d frequency ndarray is well-formed, and raises
+def validate_frequencies(frequencies, max_freq, min_freq, allow_negatives=False):
+    """Check that a 1-d frequency ndarray is well-formed, and raises
     errors if not.
 
     Parameters
@@ -831,24 +813,30 @@ def validate_frequencies(frequencies, max_freq, min_freq,
         frequencies = np.abs(frequencies)
     # Make sure no frequency values are huge
     if (np.abs(frequencies) > max_freq).any():
-        raise ValueError('A frequency of {} was found which is greater than '
-                         'the maximum allowable value of max_freq = {} (did '
-                         'you supply frequency values in '
-                         'Hz?)'.format(frequencies.max(), max_freq))
+        raise ValueError(
+            "A frequency of {} was found which is greater than "
+            "the maximum allowable value of max_freq = {} (did "
+            "you supply frequency values in "
+            "Hz?)".format(frequencies.max(), max_freq)
+        )
     # Make sure no frequency values are tiny
     if (np.abs(frequencies) < min_freq).any():
-        raise ValueError('A frequency of {} was found which is less than the '
-                         'minimum allowable value of min_freq = {} (did you '
-                         'supply frequency values in '
-                         'Hz?)'.format(frequencies.min(), min_freq))
+        raise ValueError(
+            "A frequency of {} was found which is less than the "
+            "minimum allowable value of min_freq = {} (did you "
+            "supply frequency values in "
+            "Hz?)".format(frequencies.min(), min_freq)
+        )
     # Make sure frequency values are 1-d np ndarrays
     if frequencies.ndim != 1:
-        raise ValueError('Frequencies should be 1-d numpy ndarray, '
-                         'but shape={}'.format(frequencies.shape))
+        raise ValueError(
+            "Frequencies should be 1-d numpy ndarray, "
+            "but shape={}".format(frequencies.shape)
+        )
 
 
 def has_kwargs(function):
-    r'''Determine whether a function has \*\*kwargs.
+    r"""Determine whether a function has \*\*kwargs.
 
     Parameters
     ----------
@@ -859,22 +847,18 @@ def has_kwargs(function):
     -------
     True if function accepts arbitrary keyword arguments.
     False otherwise.
-    '''
+    """
+    sig = inspect.signature(function)
 
-    if six.PY2:
-        return inspect.getargspec(function).keywords is not None
-    else:
-        sig = inspect.signature(function)
+    for param in list(sig.parameters.values()):
+        if param.kind == param.VAR_KEYWORD:
+            return True
 
-        for param in sig.parameters.values():
-            if param.kind == param.VAR_KEYWORD:
-                return True
-
-        return False
+    return False
 
 
 def filter_kwargs(_function, *args, **kwargs):
-    """Given a function and args and keyword args to pass to it, call the function
+    r"""Given a function and args and keyword args to pass to it, call the function
     but using only the keyword arguments which it accepts.  This is equivalent
     to redefining the function with an additional \*\*kwargs to accept slop
     keyword args.
@@ -886,15 +870,16 @@ def filter_kwargs(_function, *args, **kwargs):
     ----------
     _function : callable
         Function to call.  Can take in any number of args or kwargs
-
+    *args
+    **kwargs
+        Arguments and keyword arguments to _function.
     """
-
     if has_kwargs(_function):
         return _function(*args, **kwargs)
 
     # Get the list of function arguments
-    func_code = six.get_function_code(_function)
-    function_args = func_code.co_varnames[:func_code.co_argcount]
+    func_code = _function.__code__
+    function_args = func_code.co_varnames[: func_code.co_argcount]
     # Construct a dict of those kwargs which appear in the function
     filtered_kwargs = {}
     for kwarg, value in list(kwargs.items()):
@@ -905,7 +890,7 @@ def filter_kwargs(_function, *args, **kwargs):
 
 
 def intervals_to_durations(intervals):
-    """Converts an array of n intervals to their n durations.
+    """Convert an array of n intervals to their n durations.
 
     Parameters
     ----------
@@ -926,7 +911,7 @@ def intervals_to_durations(intervals):
 
 
 def hz_to_midi(freqs):
-    '''Convert Hz to MIDI numbers
+    """Convert Hz to MIDI numbers
 
     Parameters
     ----------
@@ -938,12 +923,12 @@ def hz_to_midi(freqs):
     midi : number or ndarray
         MIDI note numbers corresponding to input frequencies.
         Note that these may be fractional.
-    '''
+    """
     return 12.0 * (np.log2(freqs) - np.log2(440.0)) + 69.0
 
 
 def midi_to_hz(midi):
-    '''Convert MIDI numbers to Hz
+    """Convert MIDI numbers to Hz
 
     Parameters
     ----------
@@ -954,5 +939,24 @@ def midi_to_hz(midi):
     -------
     freqs : number or ndarray
         Frequency/frequencies in Hz corresponding to `midi`
-    '''
-    return 440.0 * (2.0 ** ((midi - 69.0)/12.0))
+    """
+    return 440.0 * (2.0 ** ((midi - 69.0) / 12.0))
+
+
+def deprecated(*, version, version_removed):
+    """Mark a function as deprecated.
+
+    Using the decorated (old) function will result in a warning.
+    """
+
+    def __wrapper(func, *args, **kwargs):
+        """Warn the user, and then proceed."""
+        warnings.warn(
+            f"{func.__module__}.{func.__name__}\n\tDeprecated as of mir_eval version {version}."
+            f"\n\tIt will be removed in mir_eval version {version_removed}.",
+            category=FutureWarning,
+            stacklevel=3,  # Would be 2, but the decorator adds a level
+        )
+        return func(*args, **kwargs)
+
+    return decorator(__wrapper)
